@@ -46,10 +46,11 @@
  *    <i>bool:hilighted<sub>numitems</sub></i>\n
  *    <i>text:item-title<sub>numitems</sub></i>\n
  *    <i>text:item-description<sub>numitems</sub></i>' - refreshes the current menu\n
- *  - '<tt>status </tt><i>text</i>' - sets the status bar to <i>text</i> (until the next refresh)
+ *  - '<tt>status</tt>\n
+ *    <i>text</i>' - sets the status bar to <i>text</i> (until the next refresh)
  *  - '<tt>load</tt>\n
  *    <i>text:classname</i>\n
- *    <i>text:instancename</i>
+ *    <i>text:instancename</i>\n
  *    <i>int:port</i>\n
  *    [<i>arg1</i> [<i>arg2</i> [...]]]' - tells the GUI to load the java class named <i>classname</i>, and have it connect to <i>port</i>, passing it the argument list.
  *    <i>classname</i> should contain a constructor of the form <tt>Classname(String </tt><i>host</i>, <tt>int </tt><i>port</i>, <tt>String </tt><i>args</i><tt>[])</tt>
@@ -93,8 +94,8 @@
  */
 class Controller : public BehaviorBase, public EventTrapper {
 public:
-	Controller() : display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(NULL), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), isControlling(false), gui_comm(NULL)  {init();}	//!< Constructor
-	Controller(ControlBase* r) : display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(r), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), isControlling(false), gui_comm(NULL) { init(); } //!< Constructor, sets a default root control
+	Controller() : BehaviorBase("Controller"), EventTrapper(), display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(NULL), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), isControlling(false), gui_comm(NULL)  {init();}	//!< Constructor
+	Controller(ControlBase* r) : BehaviorBase("Controller"), EventTrapper(), display(MotionManager::invalid_MC_ID), estop_id(MotionManager::invalid_MC_ID), root(r), cmdstack(), last_time(0), cur_time(0), nextEv_val(0), nextEv_dur(0), prevEv_val(0), prevEv_dur(0), alreadyGotBoth(false), isControlling(false), gui_comm(NULL) { init(); } //!< Constructor, sets a default root control
 	virtual ~Controller() {
 		cout << "~Controller()..." << endl;
 		delete root;
@@ -127,9 +128,8 @@ public:
 
 	Controller& setEStopID(MotionManager::MC_ID estopid); //!< Sets the emergency stop MC to monitor for pausing
 	
-	virtual std::string getName() const { return "Controller"; }
 	static std::string getClassDescription() { return "Provides interface for activating/deactivating controls (and through them, behaviors)"; }
-	
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 
 	static void loadGUI(const std::string& type, const std::string& name, unsigned int port) {loadGUI(type,name,port,std::vector<std::string>());} //!< attempts to open a Java object on the desktop
@@ -211,10 +211,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.29 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.31 $
  * $State: Exp $
- * $Date: 2004/03/24 05:35:00 $
+ * $Date: 2004/11/11 01:45:31 $
  */
 
 #endif
