@@ -86,7 +86,7 @@ public:
 	virtual std::string getDescription() const {
 		if(mybeh==NULL)
 			return ControlBase::getDescription();
-		return mybeh->getDescription();
+		return "Class "+mybeh->getClassName()+": "+mybeh->getDescription();
 	}
 	
 protected:
@@ -224,11 +224,13 @@ protected:
 	virtual void startmine() {
 		if(!retained) {
 			mybeh=Al::construct();
+			mybeh->setName(getName());
 			if(behgrp!=NULL)
 				behgrp->curBehavior=mybeh;
 		} else {
 			if(mybeh==NULL) {
 				mybeh=Al::construct();
+				mybeh->setName(getName());
 				mybeh->AddReference();
 			}
 			if(behgrp!=NULL)
@@ -263,10 +265,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/02/18 21:11:25 $
+ * $Date: 2004/11/12 00:05:03 $
  */
 
 #endif
