@@ -2,6 +2,7 @@
 #include "Motion/MMAccessor.h"
 #include "Motion/LedMC.h"
 #include "Shared/string_util.h"
+#include "SoundPlay/SoundManager.h"
 #include "Wireless/Wireless.h"
 #include <iomanip>
 #include <sstream>
@@ -410,9 +411,9 @@ float ControlBase::hilightsAvg() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.8 $
- * $State: Rel $
- * $Date: 2003/08/06 22:50:41 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
+ * $State: Exp $
+ * $Date: 2004/11/04 03:01:31 $
  */
 
