@@ -4,7 +4,6 @@
 
 #include "Events/EventBase.h"
 #include "Motion/MotionManager.h"
-#include "SoundPlay/SoundManager.h"
 #include "Shared/Config.h"
 #include "Wireless/Socket.h"
 #include <string>
@@ -168,9 +167,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2004/10/07 22:15:37 $
+ * $Date: 2004/11/04 03:01:31 $
  */
 #endif
