@@ -9,6 +9,7 @@
 #include "Events/LocomotionEvent.h"
 #include "Events/TextMsgEvent.h"
 #include "Events/VisionObjectEvent.h"
+#include "SoundPlay/SoundManager.h"
 
 EventLogger::EventLogger() : ControlBase("Event Logger","Allows you to see/log all of the un-trapped events as they are generated"), logfilePath(), logfile(), verbosity(0) {
 	for(unsigned int i=0; i<EventBase::numEGIDs; i++) {
@@ -108,8 +109,8 @@ void EventLogger::checkLogFile() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/10/07 22:15:21 $
+ * $Date: 2004/11/04 03:01:32 $
  */
