@@ -11,9 +11,6 @@ public:
 	//! Constructor
 	ProfilerCheckControl() : ControlBase("Profiler Check","Reports time spent in all of the profiled sections in all processes") {}
 
-	//! Destructor
-	~ProfilerCheckControl() {}
-	
 	//! Prints a report to sout
 	virtual ControlBase * activate(MotionManager::MC_ID, Socket *) {
 		sout->printf("~~~ Main: ~~~\n%s",state->mainProfile.report().c_str());
@@ -27,10 +24,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
- * $State: Rel $
- * $Date: 2003/07/25 20:18:04 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2004/11/11 20:34:59 $
  */
 
 #endif
