@@ -7,6 +7,7 @@
 #include "Events/TextMsgEvent.h"
 #include "Events/VisionObjectEvent.h"
 #include "Shared/WorldState.h"
+#include "SoundPlay/SoundManager.h"
 
 SensorObserverControl::SensorObserverControl()
 	: ControlBase("Sensor Observer","Allows you to see/log the sensor data"), logfilePath(), logfile(), helpCtl(NULL), sensorCtl(NULL), buttonCtl(NULL), outputCtl(NULL), dutyCtl(NULL), consoleCtl(NULL), fileCtl(NULL), numListeners(0)
@@ -132,8 +133,8 @@ void SensorObserverControl::checkLogFile() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:04 $
+ * $Date: 2004/11/04 03:01:32 $
  */
