@@ -6,6 +6,7 @@
 #include "Behaviors/Controller.h"
 #include "Shared/WorldState.h"
 #include "Shared/string_util.h"
+#include "SoundPlay/SoundManager.h"
 #include <stdlib.h>
 
 char * WalkCalibration::datanames[WalkCalibration::NUM_SRC] = { "fs","fr","sr","br","bs","rr" };
@@ -912,9 +913,9 @@ void WalkCalibration::addSample(std::vector<float*>& dat, float x, float y, floa
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/03/01 21:17:08 $
+ * $Date: 2004/11/04 03:01:32 $
  */
 
