@@ -8,6 +8,7 @@
 #include "Motion/WaypointWalkMC.h"
 #include "Motion/WalkMC.h"
 #include "Motion/MMAccessor.h"
+#include "SoundPlay/SoundManager.h"
 
 WaypointWalkControl::WaypointWalkControl()
 	: ControlBase("WaypointWalkControl","Allows interactive control and execution of a set of waypoints"),
@@ -243,9 +244,9 @@ ControlBase* WaypointWalkControl::WaypointEditControl::doSelect() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/04 03:01:32 $
  */
 
