@@ -13,7 +13,7 @@
 class ASCIIVisionBehavior : public BehaviorBase {
 public:
 	//! constructor
-	ASCIIVisionBehavior() : BehaviorBase() {}
+	ASCIIVisionBehavior() : BehaviorBase("ASCIIVisionBehavior") {}
 
 	static const unsigned int charMapSize=64;
 	static const char charMap[charMapSize];
@@ -30,9 +30,8 @@ public:
 
 	virtual void processEvent(const EventBase& e);
 
-	virtual std::string getName() const { return "ASCIIVisionBehavior"; }
-
 	static std::string getClassDescription() { return "streams low-resolution ASCII-art of the camera image to sout"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	
@@ -43,10 +42,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/10/19 00:46:54 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
