@@ -17,7 +17,7 @@
 class AlanBehavior : public BehaviorBase {
 public:
 	AlanBehavior()
-		: BehaviorBase(), pose_id(MotionManager::invalid_MC_ID)
+		: BehaviorBase("AlanBehavior"), pose_id(MotionManager::invalid_MC_ID)
 	{}
 	
 	virtual void DoStart() {
@@ -97,15 +97,14 @@ public:
 		}
 	}
 	
-	virtual std::string getName() const {
-		// Name is used for menus, or debugging.
-		return "AlanBehavior";
-	}
-	
 	static std::string getClassDescription() {
 		// This string will be shown by the HelpControl or by the tooltips of the Controller GUI
 		return "Lifts the left/right front legs higher as more pressure is applied to the front/back head buttons";
 	}
+	virtual std::string getDescription() const {
+		// We override this function to return the string we supplied above (not required, but nice)
+		return getClassDescription();
+	}
 	
 protected:
 	MotionManager::MC_ID pose_id; //!< ID of PostureMC, set up in DoStart() and used in processEvent()
@@ -116,10 +115,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
