@@ -15,7 +15,7 @@
 class AutoGetupBehavior : public BehaviorBase {
 public:
 	//! constructor
-	AutoGetupBehavior() : BehaviorBase(), back(0), side(0), gamma(.9), sensitivity(.85*.85), waiting(false) {}
+	AutoGetupBehavior() : BehaviorBase("AutoGetupBehavior"), back(0), side(0), gamma(.9), sensitivity(.85*.85), waiting(false) {}
 	//! destructor
 	virtual ~AutoGetupBehavior() {}
 
@@ -58,8 +58,8 @@ public:
 			waiting=true;
 		}
 	}
-	virtual std::string getName() const { return "AutoGetupBehavior"; }
 	static std::string getClassDescription() { return "Monitors gravity's influence on the accelerometers - if it seems the robot has fallen over, it runs appropriate getup script"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
 	float back;          //!< exponential average of backwards accel
@@ -74,10 +74,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
