@@ -21,7 +21,7 @@ class BanditMachine : public StateNode {
 public:
 	//!constructor
 	BanditMachine()
-		: StateNode("Bandit Machine",NULL), stare(NULL), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
+		: StateNode("BanditMachine","BanditMachine",NULL), stare(NULL), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
 	{
 		stare=new StareAtBallBehavior();
 		stare->AddReference();
@@ -39,6 +39,7 @@ public:
 	}
 
 	static std::string getClassDescription() { return "Plays k-armed bandit with a computer"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 	virtual void setup() {
 		StateNode *wait=start=addNode(new WaitNode("Wait",this,bandit));
@@ -83,7 +84,7 @@ protected:
 		 *  @param p the parent node
 		 *  @param idx the joint index of the paw to move
 		 */
-		PressNode(const char* n, StateNode* p, unsigned int idx) : StateNode(n,p), press_id(MotionManager::invalid_MC_ID), index(idx) {
+		PressNode(const char* n, StateNode* p, unsigned int idx) : StateNode("PressNode",n,p), press_id(MotionManager::invalid_MC_ID), index(idx) {
 			SharedObject<MotionSequenceMC<MotionSequence::SizeSmall> > press;
 			press->setPlayTime(0);
 			press->setOutputCmd(idx,.6);
@@ -129,7 +130,7 @@ protected:
 		 *  @param right the PressNode to go to if the right paw is chosen
 		 */
 		DecideNode(const char* n, StateNode* p, karmedbanditExp3_1& bandito, StateNode* left, StateNode* right)
-			: StateNode(n,p), b(bandito), l(left), r(right)
+			: StateNode("DecideNode",n,p), b(bandito), l(left), r(right)
 		{}
 		virtual void DoStart() {
 			StateNode::DoStart();
@@ -162,7 +163,7 @@ protected:
 		 * @param bandito the class to pass the reward to (if it comes)
 		 */
 		WaitNode(const char* n, StateNode* p, karmedbanditExp3_1& bandito)
-			: StateNode(n,p), b(bandito), reward(false), leds_id(MotionManager::invalid_MC_ID)
+			: StateNode("WaitNode",n,p), b(bandito), reward(false), leds_id(MotionManager::invalid_MC_ID)
 		{
 			leds_id=motman->addPersistentMotion(SharedObject<LedMC>());
 		}
@@ -216,10 +217,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.17 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
