@@ -25,7 +25,7 @@ public:
 	static const unsigned int no_power_p=14; //!< percent of 100 at which power will fail (approximate!)
 
 	//! constructor
-	BatteryMonitorBehavior() : BehaviorBase(), pose(NULL), pose_id(MotionManager::invalid_MC_ID), led_id(MotionManager::invalid_MC_ID) {}
+	BatteryMonitorBehavior() : BehaviorBase("BatteryMonitorBehavior"), pose(NULL), pose_id(MotionManager::invalid_MC_ID), led_id(MotionManager::invalid_MC_ID) {}
 	//! destructor
 	virtual ~BatteryMonitorBehavior() {}
 
@@ -94,8 +94,8 @@ public:
 			}
 		}
 	}
-	virtual std::string getName() const { return "BatteryMonitorBehavior"; }
 	static std::string getClassDescription() { return "Reports the current battery status, and starts flicks the ears to warn when it gets too low"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 	//! returns true if the warning should be active (power remaining less than high_power_p, no external power, but also checks that a power update has been received)
 	static bool shouldWarn() { return state!=NULL && state->powerFlags[PowerSourceID::BatteryConnectSID] && (state->sensors[PowerRemainOffset]*100<=high_power_p || state->powerFlags[PowerSourceID::LowPowerWarnSID]) && !state->powerFlags[PowerSourceID::ExternalPowerSID]; }
@@ -156,10 +156,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
