@@ -24,7 +24,7 @@ class CameraBehavior : public BehaviorBase {
  public:
 	//! constructor, just sets up the variables
 	CameraBehavior()
-		: BehaviorBase(), camera_click(EventBase::buttonEGID,0,EventBase::deactivateETID,150), index(0), ledID(MotionManager::invalid_MC_ID)
+		: BehaviorBase("CameraBehavior"), camera_click(EventBase::buttonEGID,0,EventBase::deactivateETID,150), index(0), ledID(MotionManager::invalid_MC_ID)
 	{}
 
 	//! Register for events
@@ -36,8 +36,9 @@ class CameraBehavior : public BehaviorBase {
 	//! Handles event processing - determines which generator to save from and writes to current file
 	virtual void processEvent(const EventBase& e);
 
-	virtual std::string getName() const { return "CameraBehavior"; } //!< returns name of behavior
 	static std::string getClassDescription() { return "Push head button to save a picture"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
+
  protected:
 	//! opens the next file to be saved to (with @a ext extension on the file name)
 	FILE * openNextFile(const std::string& ext);
@@ -60,10 +61,10 @@ class CameraBehavior : public BehaviorBase {
  * @author ejt (rewrite for new vision system)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/02/03 01:16:32 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
