@@ -10,7 +10,7 @@ class ChaseBallBehavior : public BehaviorBase {
 public:
 	//!constructor
 	ChaseBallBehavior()
-		: BehaviorBase(), headpointer_id(MotionManager::invalid_MC_ID), walker_id(MotionManager::invalid_MC_ID)
+		: BehaviorBase("ChaseBallBehavior"), headpointer_id(MotionManager::invalid_MC_ID), walker_id(MotionManager::invalid_MC_ID)
 	{}
 	//!destructor
 	virtual ~ChaseBallBehavior() {}
@@ -24,8 +24,8 @@ public:
 	//! sets the head to point at the object and sets the body to move where the head points
 	virtual void processEvent(const EventBase& event);
 			
-	virtual std::string getName() const { return "ChaseBallBehavior"; } //!< returns name of behavior
 	static std::string getClassDescription() { return "Follows ball with head and walks whereever the head is pointing"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
 	MotionManager::MC_ID headpointer_id; //!< a HeadPointerMC object
@@ -37,10 +37,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:22 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
