@@ -8,12 +8,13 @@
 //! Demonstrates (lack of) blocking using serr to (not) pinpoint a crash
 class CrashTestBehavior : public BehaviorBase {
 public:
-	CrashTestBehavior() : BehaviorBase()	{}
+	CrashTestBehavior() : BehaviorBase("CrashTestBehavior")	{}
 	
 	virtual void DoStart() {
 		//call superclass first for housekeeping:
 		BehaviorBase::DoStart();
 
+		serr->printf("I will now crash immediately following line 33\n");
 		//now do your code:
 		for(unsigned int i=0; i<100; i++) {
 			serr->printf("Hello serr!  This is %d\n",i);
@@ -23,16 +24,12 @@ public:
 		//Hate to break it to you, but we're never going to get here...
 	}
 	
-	virtual std::string getName() const {
-		// Name is used for menus, or debugging.
-		return "CrashTestBehavior";
-	}
-	
 	static std::string getClassDescription() {
 		// This string will be shown by the HelpControl or by the tooltips of the Controller GUI
 		return "A little demo of blocking output before a crash after output #33 (yes, this crashes the AIBO)";
 	}
 	
+	virtual std::string getDescription() const { return getClassDescription(); }
 };
 
 /*! @file
@@ -40,10 +37,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/08/25 01:07:45 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
 #endif
