@@ -18,7 +18,7 @@
 
 // ctor
 DriveMeBehavior::DriveMeBehavior()
-  : BehaviorBase(),
+  : BehaviorBase("DriveMeBehavior"),
     walker_id(MotionManager::invalid_MC_ID),
     stand_id(MotionManager::invalid_MC_ID),
     stand(),
@@ -109,9 +109,9 @@ void DriveMeBehavior::processEvent(const EventBase& event)
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:35 $
  */
 
