@@ -16,14 +16,14 @@ class ExploreMachine : public StateNode {
 public:
 	//!constructor
 	ExploreMachine()
-		: StateNode("ExploreMachine"), start(NULL), turn(NULL), walkid(MotionManager::invalid_MC_ID)
+		: StateNode("ExploreMachine","ExploreMachine"), start(NULL), turn(NULL), walkid(MotionManager::invalid_MC_ID)
 	{
 		setRetain(false);
 	}
 
 	//!constructor
 	ExploreMachine(const std::string& nm, StateNode* p=NULL)
-		: StateNode(nm,p), start(NULL), turn(NULL), walkid(MotionManager::invalid_MC_ID)
+		: StateNode("ExploreMachine",nm,p), start(NULL), turn(NULL), walkid(MotionManager::invalid_MC_ID)
 	{
 		setRetain(false);
 	}
@@ -102,10 +102,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.19 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
