@@ -8,7 +8,7 @@
 #include "Motion/PIDMC.h"
 
 FollowHeadBehavior::FollowHeadBehavior() :
-	BehaviorBase(),
+	BehaviorBase("FollowHeadBehavior"),
 	head_release(EventBase::buttonEGID,ChinButOffset,EventBase::activateETID,0),
 	head_lock(EventBase::buttonEGID,ChinButOffset,EventBase::deactivateETID,0),
 	clock(EventBase::timerEGID,0,EventBase::statusETID,250),
@@ -74,8 +74,8 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
  *
  * $Author: ejt $
  * $Name $
- * $Revision: 1.8 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
