@@ -39,8 +39,8 @@ class FollowHeadBehavior : public BehaviorBase {
 	/*! After every clock pulse, sets walk in direction of head */
 	virtual void processEvent(const EventBase& e);
 
-	virtual std::string getName() const { return "FollowHeadBehavior"; }
 	static std::string getClassDescription() { return "Walks whereever you point the head - press the chin button to loosen the head, release to lock it"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
  protected:
 	const EventBase head_release; //!< event mask for releasing head (chin button down)
@@ -54,10 +54,10 @@ class FollowHeadBehavior : public BehaviorBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:23 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
