@@ -8,7 +8,7 @@
 //! Demonstrates an infinite loop condition in the Main process
 class FreezeTestBehavior : public BehaviorBase {
 public:
-	FreezeTestBehavior() : BehaviorBase()	{}
+	FreezeTestBehavior() : BehaviorBase("FreezeTestBehavior")	{}
 	
 	virtual void DoStart() {
 		//call superclass first for housekeeping:
@@ -30,16 +30,11 @@ public:
 		//Hate to break it to you, but we're never going to get here...
 	}
 	
-	virtual std::string getName() const {
-		// Name is used for menus, or debugging.
-		return "FreezeTestBehavior";
-	}
-	
 	static std::string getClassDescription() {
 		// This string will be shown by the HelpControl or by the tooltips of the Controller GUI
 		return "A little demo of a Main process infinite loop freeze (yes, this hangs the AIBO)";
 	}
-	
+	virtual std::string getDescription() const { return getClassDescription(); }
 };
 
 /*! @file
@@ -47,10 +42,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2004/08/27 22:10:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
