@@ -17,7 +17,7 @@ class HeadLevelBehavior : public BehaviorBase {
  public:
 	//! constructor
 	HeadLevelBehavior()
-		: BehaviorBase(),
+		: BehaviorBase("HeadLevelBehavior"),
 			head_release(EventBase::buttonEGID,0,EventBase::activateETID,0),
 			head_lock(EventBase::buttonEGID,0,EventBase::deactivateETID,0),
 			head(),
@@ -69,8 +69,8 @@ class HeadLevelBehavior : public BehaviorBase {
 		} else
 			ASSERTRET(false,"received unasked for event "<<event.getName());
 	}
-	virtual std::string getName() const { return "HeadLevelBehavior"; }
 	static std::string getClassDescription() { return "Uses the internal accelerometers to attempt to keep the head level."; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
  protected:
 	EventBase head_release; //!< event mask for releasing head (chin button down)
@@ -85,10 +85,10 @@ class HeadLevelBehavior : public BehaviorBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
