@@ -8,7 +8,11 @@
 //! Demonstrates serr, sout, and cout
 class HelloWorldBehavior : public BehaviorBase {
 public:
-	HelloWorldBehavior() : BehaviorBase()	{}
+	//Note that we pass the name of our class as an argument to the
+	//BehaviorBase constructor.  This is used for the default name for
+	//instances of this class, and may allow more readable debugging
+	//information
+	HelloWorldBehavior() : BehaviorBase("HelloWorldBehavior")	{}
 	
 	virtual void DoStart() {
 		//call superclass first for housekeeping:
@@ -25,18 +29,19 @@ public:
 			printf("Hello printf!  This is %d\n",i);
 
 		//we'll just stop right away since this Behavior has no 'active' state.
-		DoStop();
-	}
-	
-	virtual std::string getName() const {
-		// Name is used for menus, or debugging.
-		return "HelloWorldBehavior";
+		DoStop(); //Note that you could also override this DoStop function...
 	}
 	
 	static std::string getClassDescription() {
-		// This string will be shown by the HelpControl or by the tooltips of the Controller GUI
+		// This string will be shown by the HelpControl or by the tooltips
+		// of the Controller GUI (not required, but nice)
 		return "A little demo of text output";
 	}
+	virtual std::string getDescription() const {
+		// We override this function to return the string we supplied
+		// above (not required, but nice)
+		return getClassDescription();
+	}
 	
 };
 
@@ -45,10 +50,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/10/07 00:59:33 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
