@@ -17,7 +17,7 @@ class KinematicSampleBehavior : public BehaviorBase {
 public:
 	//! constructor
 	KinematicSampleBehavior()
-		: BehaviorBase(), lastLeg(LFrLegOrder), poseID(MotionManager::invalid_MC_ID)
+		: BehaviorBase("KinematicSampleBehavior"), lastLeg(LFrLegOrder), poseID(MotionManager::invalid_MC_ID)
 	{ }
 
 	virtual void DoStart() {
@@ -95,9 +95,8 @@ public:
 		}
 	}
 
-	virtual std::string getName() const { return "KinematicSampleBehavior"; }
-
 	static std::string getClassDescription() { return "Uses kinematics to mirror leg positions (note that it mirrors the paw position - not necessarily the joint angles used to get there!)"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	unsigned int getIndex(LegOrder_t leg) {
@@ -113,10 +112,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
