@@ -17,7 +17,7 @@ class KinematicSampleBehavior2 : public BehaviorBase {
 public:
 	//! constructor
 	KinematicSampleBehavior2()
-		: BehaviorBase(), lastLeg(LFrLegOrder), poseID(MotionManager::invalid_MC_ID)
+		: BehaviorBase("KinematicSampleBehavior2"), lastLeg(LFrLegOrder), poseID(MotionManager::invalid_MC_ID)
 	{ }
 
 	virtual void DoStart() {
@@ -150,9 +150,8 @@ public:
 		}
 	}
 
-	virtual std::string getName() const { return "KinematicSampleBehavior2"; }
-
 	static std::string getClassDescription() { return "Uses kinematics to make the back toe (Toe{LR}BkPaw) touch the lower thigh (Lower{LeftBackL,RightBackR}FrThigh)"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	LegOrder_t lastLeg;
@@ -164,10 +163,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/10/19 17:06:51 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
