@@ -11,7 +11,7 @@
 class MCRepeater : public BehaviorBase {
 public:
 	//! constructor
-	MCRepeater(const SharedObjectBase* sharedmc) : BehaviorBase(), mc(sharedmc) {}
+	MCRepeater(const SharedObjectBase* sharedmc) : BehaviorBase("MCRepeater"), mc(sharedmc) {}
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
@@ -30,9 +30,8 @@ public:
 		erouter->addListener(this,EventBase::motmanEGID,id,EventBase::deactivateETID);
 	}
 
-	virtual std::string getName() const { return "MCRepeater"; }
-
 	static std::string getClassDescription() { return "Sends a given MotionCommand to MotionManager, waits until it autoprunes, and then sends it again."; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	const SharedObjectBase* mc; //!< the motion command being repeated
@@ -47,10 +46,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
