@@ -12,7 +12,7 @@
 class MotionStressTestBehavior : public BehaviorBase {
 public:
 	//! constructor
-	MotionStressTestBehavior() : BehaviorBase(), nextLeg(RBkLegOrder), curMotions() {}
+	MotionStressTestBehavior() : BehaviorBase("MotionStressTestBehavior"), nextLeg(RBkLegOrder), curMotions() {}
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
@@ -74,9 +74,8 @@ public:
 		cout << get_time() << "\tAdded id " << id << endl;
 	}
 
-	virtual std::string getName() const { return "MotionStressTestBehavior"; }
-
 	static std::string getClassDescription() { return "uses a separate MotionCommand for each of several joints to test for region leaks"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	LegOrder_t nextLeg;
@@ -88,10 +87,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
