@@ -62,11 +62,12 @@ void PaceTargetsMachine::DoStart() {
 }
 
 void PaceTargetsMachine::teardown() {
-	//preload the sounds
+	//release the sounds
 	sndman->ReleaseFile("cutey.wav");
 	sndman->ReleaseFile("barkmed.wav");
 	sndman->ReleaseFile("whimper.wav");
 	sndman->ReleaseFile("fart.wav");
+	StateNode::teardown();
 }
 
 /*! @file
@@ -74,9 +75,9 @@ void PaceTargetsMachine::teardown() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2003/12/08 00:20:57 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
