@@ -9,7 +9,7 @@
 class PaceTargetsMachine : public StateNode {
 public:
 	//!constructor
-	PaceTargetsMachine() : StateNode("PaceTargetsMachine"), start(NULL) {}
+	PaceTargetsMachine() : StateNode("PaceTargetsMachine","PaceTargetsMachine"), start(NULL) {}
 
 	virtual void setup();
 	virtual void DoStart();
@@ -29,10 +29,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:56 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
