@@ -15,7 +15,7 @@ using namespace std;
 class RelaxBehavior : public BehaviorBase {
 public:
 	//! contstructor
-	RelaxBehavior() : BehaviorBase(), pidMCID(MotionManager::invalid_MC_ID) {}
+	RelaxBehavior() : BehaviorBase("RelaxBehavior"), pidMCID(MotionManager::invalid_MC_ID) {}
 	
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
@@ -36,7 +36,8 @@ public:
 		motman->addPrunableMotion(SharedObject<PIDMC>(1));
 		BehaviorBase::DoStop();
 	}
-	virtual std::string getName() const { return "RelaxBehavior"; }
+	static std::string getClassDescription() { return "Sets PID parameters for all applicable joints to 0, allowing the joints to move freely, reducing noise and power consumption"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 protected:
 	MotionManager::MC_ID pidMCID; //!< the id for the pid motion command
 };
@@ -49,8 +50,8 @@ protected:
  * @author ejt (Modifications)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
