@@ -19,7 +19,7 @@ class SimpleChaseBallBehavior : public BehaviorBase {
 public:
 	//!constructor
 	SimpleChaseBallBehavior()
-		: BehaviorBase(), walker_id(MotionManager::invalid_MC_ID)
+		: BehaviorBase("SimpleChaseBallBehavior"), walker_id(MotionManager::invalid_MC_ID)
 	{}
 	//!destructor
 	virtual ~SimpleChaseBallBehavior() {}
@@ -49,8 +49,6 @@ public:
 		}
 	}
 			
-	virtual std::string getName() const { return "SimpleChaseBallBehavior"; } 
-
 protected:
 	MotionManager::MC_ID walker_id;      //!< a WalkMC object
 };
@@ -60,10 +58,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
