@@ -22,7 +22,7 @@ class SoundTestBehavior : public BehaviorBase {
 public:
 	//! Constructor
 	SoundTestBehavior()
-		: BehaviorBase(), curplay(SoundManager::invalid_Play_ID), endtime(0),
+		: BehaviorBase("SoundTestBehavior"), curplay(SoundManager::invalid_Play_ID), endtime(0),
 			LFr(EventBase::buttonEGID,LFrPawOffset,EventBase::activateETID),
 			RFr(EventBase::buttonEGID,RFrPawOffset,EventBase::activateETID),
 			LBk(EventBase::buttonEGID,LBkPawOffset,EventBase::activateETID),
@@ -79,8 +79,9 @@ public:
 	}
 
 	//! returns name to system
-	virtual std::string getName() const { return "SoundTestBehavior"; }
 	static std::string getClassDescription() { return "Plays different sounds when buttons are pressed.  Holding the chin button queues the sounds."; }
+	virtual std::string getDescription() const { return getClassDescription(); }
+
 protected:
 	//! called when a button is pressed - checks if it should enqueue or just play
 	void play(const char* name) {
@@ -120,10 +121,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:42 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
