@@ -10,12 +10,12 @@ inline double DtoR(double deg) { return (deg/180.0*M_PI); }
 
 void StareAtBallBehavior::DoStart() {
 	BehaviorBase::DoStart();
-	headpointer_id = motman->addMotion(SharedObject<HeadPointerMC>());
+	headpointer_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
 	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visPinkBallSID);
 }
 
 void StareAtBallBehavior::DoStop() {
-	erouter->forgetListener(this);
+	erouter->removeListener(this);
 	motman->removeMotion(headpointer_id);
 	BehaviorBase::DoStop();
 }
