@@ -10,7 +10,7 @@ class StareAtBallBehavior : public BehaviorBase {
 public:
 	//!constructor
 	StareAtBallBehavior()
-		: BehaviorBase(), headpointer_id(MotionManager::invalid_MC_ID)
+		: BehaviorBase("StareAtBallBehavior"), headpointer_id(MotionManager::invalid_MC_ID)
 	{}
 	//!destructor
 	virtual ~StareAtBallBehavior() {}
@@ -24,8 +24,8 @@ public:
 	//! sets the head to point at the object and sets the body to move where the head points
 	virtual void processEvent(const EventBase& event);
 			
-	virtual std::string getName() const { return "StareAtBallBehavior"; }
-	static std::string getClassDescription() { return "Tracks any objects seen by the vision system"; }
+	static std::string getClassDescription() { return "Tracks any pink objects seen by the vision system"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
 	MotionManager::MC_ID headpointer_id; //!< a HeadPointerMC object
@@ -36,10 +36,10 @@ protected:
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:23 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2004/11/12 00:05:03 $
  */
 
 #endif
