@@ -10,7 +10,7 @@
 class ToggleHeadLightBehavior : public BehaviorBase {
 public:
 	//! constructor
-	ToggleHeadLightBehavior() : BehaviorBase(), light_id(MotionManager::invalid_MC_ID) {}
+	ToggleHeadLightBehavior() : BehaviorBase("ToggleHeadLightBehavior"), light_id(MotionManager::invalid_MC_ID) {}
 
 	//! opens the head light
 	virtual void DoStart() {
@@ -28,8 +28,7 @@ public:
 	}
 
 	static std::string getClassDescription() { return "Opens or closes the head light on an ERS-220"; }
-
-	std::string getName() const { return "ToggleHeadLightBehavior"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
 	MotionManager::MC_ID light_id; //!< id value of the PostureMC used to control the light
@@ -40,10 +39,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
