@@ -12,7 +12,7 @@ class WalkToTargetMachine : public StateNode {
 public:
 	//!constructor, pass success (close), failure (lost), and parent nodes, and VisionObjectSourceID_t
 	WalkToTargetMachine(unsigned int obj,StateNode* c=NULL, StateNode* l=NULL,StateNode* p=NULL)
-		: StateNode("WalkToTarget",p),tracking(obj),timeout(NULL),closeTrans(NULL),close(c),lost(l),
+		: StateNode("WalkToTarget","WalkToTarget",p),tracking(obj),timeout(NULL),closeTrans(NULL),close(c),lost(l),
 			walker_id(MotionManager::invalid_MC_ID), headpointer_id(MotionManager::invalid_MC_ID) 
 	{}
 	
@@ -24,6 +24,7 @@ public:
 	virtual void teardown();
 
 	static std::string getClassDescription() { return "walks towards a visual target until it gets \"close\""; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 	//uses head to watch ball, walks towards it
 	virtual void processEvent(const EventBase& event);
@@ -51,10 +52,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:56 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
