@@ -19,7 +19,7 @@
 class WorldStateVelDaemon : public BehaviorBase, public EventTrapper {
 public:
 	//! constructor
-	WorldStateVelDaemon() : BehaviorBase(), estopTime(1), old_x(0), old_y(0), old_a(0) {}
+	WorldStateVelDaemon() : BehaviorBase("WorldStateVelDaemon"), estopTime(1), old_x(0), old_y(0), old_a(0) {}
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
@@ -70,9 +70,8 @@ public:
 		}
 	}
 
-	virtual std::string getName() const { return "WorldStateVelDaemon"; }
-
 	static std::string getClassDescription() { return "Keeps the WorldState's velocity fields up to date"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	unsigned int estopTime; //!< time estop activation was received
@@ -86,10 +85,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:04 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
