@@ -40,7 +40,7 @@ class Aibo3DControllerBehavior : public BehaviorBase {
  public:
 	//! constructor
 	Aibo3DControllerBehavior() :
-	  BehaviorBase(),
+	  BehaviorBase("Aibo3DControllerBehavior"),
 	  rcontrol_id(MotionManager::invalid_MC_ID),
 	  cmdsock(NULL),
     fbuf((char*)val), pos(0)
@@ -110,12 +110,13 @@ class Aibo3DControllerBehavior : public BehaviorBase {
 	//! returns port number the Java GUI should connect to
 	virtual unsigned int getPort() const { return config->main.aibo3d_port; }
 
-	virtual std::string getName() const { return "Aibo 3D"; } //!< returns name of behavior
 	static std::string getClassDescription() { 
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.aibo3d_port);
 		return std::string("Listens to aibo3d control commands coming in from port ")+tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
+
 };
 
 
@@ -130,10 +131,10 @@ int aibo3dcontrollercmd_callback(char *buf, int bytes) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
