@@ -23,7 +23,7 @@ public:
 public:
 	//! constructor
 	EStopControllerBehavior(MotionManager::MC_ID estop)
-		: BehaviorBase(),
+		: BehaviorBase("EStopControllerBehavior"),
 			cmdsock(NULL),
 			estop_id(estop)
 	{
@@ -40,12 +40,12 @@ public:
 
 	virtual void processEvent(const EventBase &);
 
-	virtual std::string getName() const { return "EStop Remote Control"; }
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.estopControl_port);
 		return std::string("Listens to estop commands coming in from port ")+tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 	virtual void runCommand(const std::string& s); //!< processes a string received from wireless
 
@@ -67,10 +67,10 @@ private:
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/01/14 20:44:31 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
