@@ -53,7 +53,7 @@ class HeadPointControllerBehavior : public BehaviorBase {
  public:
 	//! constructor
 	HeadPointControllerBehavior() :
-	  BehaviorBase(),
+	  BehaviorBase("HeadPointControllerBehavior"),
 	  head_id(MotionManager::invalid_MC_ID),
 	  t(0), p(0), r(0),
 	  theLastOne(theOne),
@@ -69,12 +69,12 @@ class HeadPointControllerBehavior : public BehaviorBase {
 	//! The only event we could possibly receive is the stop-if-no-heartbeat timer.
 	virtual void processEvent(const EventBase &) {}
 
-	virtual std::string getName() const { return "Head Remote Control"; }
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.headControl_port);
 		return std::string("Listens to head control commands coming in from port ")+tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 };
 
 /*! @file
@@ -82,10 +82,10 @@ class HeadPointControllerBehavior : public BehaviorBase {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/10/14 21:59:14 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
