@@ -8,7 +8,7 @@
 #include "Shared/ProjectInterface.h"
 
 RawCamBehavior::RawCamBehavior()
-	: BehaviorBase(), visRaw(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0)
+	: BehaviorBase("RawCamBehavior"), visRaw(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0)
 {}
 
 void
@@ -16,6 +16,10 @@ RawCamBehavior::DoStart() {
 	BehaviorBase::DoStart();
 	
 	std::vector<std::string> args;
+	args.push_back("raw");
+	char port[50];
+	snprintf(port,50,"%d",config->vision.rawcam_port);
+	args.push_back(port);
 	if(config->vision.rawcam_transport==0) {
 		max_buf=UDP_WIRELESS_BUFFER_SIZE;
 		visRaw=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
@@ -289,9 +293,9 @@ RawCamBehavior::closePacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
