@@ -8,7 +8,7 @@
 #include "Vision/RLEGenerator.h"
 
 SegCamBehavior::SegCamBehavior()
-	: BehaviorBase(), visRLE(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0)
+	: BehaviorBase("SegCamBehavior"), visRLE(NULL), packet(NULL), cur(NULL), avail(0), max_buf(0)
 {
 }
 
@@ -17,6 +17,10 @@ SegCamBehavior::DoStart() {
 	BehaviorBase::DoStart();
 	
 	std::vector<std::string> args;
+	args.push_back("rle");
+	char port[50];
+	snprintf(port,50,"%d",config->vision.rle_port);
+	args.push_back(port);
 	if(config->vision.rle_transport==0) {
 		max_buf=UDP_WIRELESS_BUFFER_SIZE;
 		visRLE=wireless->socket(SocketNS::SOCK_DGRAM, 1024, max_buf);
@@ -167,9 +171,9 @@ SegCamBehavior::closePacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
