@@ -53,13 +53,12 @@ public:
 
 	virtual void processEvent(const EventBase& e);
 
-	virtual std::string getName() const { return "SegCamServer"; }
-
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->vision.rle_port);
 		return std::string("Forwards segmented images from camera over port ")+tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	//! opens a new packet, writes header info; returns true if open, false if otherwise open (check cur==NULL for error)
@@ -85,10 +84,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/09/28 22:12:30 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
