@@ -11,7 +11,7 @@
 class ViewWMVarsBehavior : public BehaviorBase {
 public:
 	//! constructor
-	ViewWMVarsBehavior() : BehaviorBase() {}
+	ViewWMVarsBehavior() : BehaviorBase("ViewWMVarsBehavior") {}
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart();
@@ -25,12 +25,12 @@ public:
 		BehaviorBase::DoStop();
 	}
 
-	virtual std::string getName() const { return "View WMVars"; }
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.wmmonitor_port);
 		return std::string("Brings up the WatchableMemory GUI on port ")+tmp+std::string(" (connects to WMMonitorBehavior, this just launches the GUI)");
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 };
 
 /*! @file
@@ -38,10 +38,10 @@ public:
  * @author ejt (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/04/16 20:17:22 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
