@@ -1,5 +1,6 @@
 #include "WalkControllerBehavior.h"
 #include "Behaviors/Controller.h"
+#include "SoundPlay/SoundManager.h"
 
 WalkControllerBehavior* WalkControllerBehavior::theOne = NULL;
 
@@ -157,9 +158,9 @@ int WalkControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/04 03:01:32 $
  */
 
