@@ -10,7 +10,6 @@
 #include "Motion/MMAccessor.h"
 #include "Events/EventRouter.h"
 #include "Events/EventBase.h"
-#include "SoundPlay/SoundManager.h"
 #include "Shared/Config.h"
 
 //! Listens to control commands coming in from the command port for remotely controlling the walk
@@ -66,7 +65,7 @@ class WalkControllerBehavior : public BehaviorBase {
  public:
 	//! constructor
 	WalkControllerBehavior() :
-	  BehaviorBase(),
+	  BehaviorBase("WalkControllerBehavior"),
 		shared_walker(),
 	  dx(0), dy(0), da(0),
 	  theLastOne(theOne),
@@ -89,12 +88,12 @@ class WalkControllerBehavior : public BehaviorBase {
 		walker->setTargetVelocity(0,0,0);
 	}
 
-	virtual std::string getName() const { return "Walk Remote Control"; }
 	static std::string getClassDescription() {
 		char tmp[20];
 		sprintf(tmp,"%d",config->main.walkControl_port);
 		return std::string("Listens to walk control commands coming in from port ")+tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 };
 
 /*! @file
@@ -104,10 +103,10 @@ class WalkControllerBehavior : public BehaviorBase {
  * @author PA Gov. School for the Sciences 2003 Team Project - Haoqian Chen, Yantian Martin, Jon Stahlman (modifications)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/12/11 05:49:30 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif 
