@@ -5,7 +5,7 @@
 #include "Events/EventRouter.h"
 
 WorldStateSerializerBehavior::WorldStateSerializerBehavior()
-	: BehaviorBase(), wsJoints(NULL), wsPIDs(NULL)
+	: BehaviorBase("WorldStateSerializerBehavior"), wsJoints(NULL), wsPIDs(NULL)
 {
 	wsJoints=wireless->socket(SocketNS::SOCK_STREAM, 1024, 2048);
   wireless->setDaemon(wsJoints);
@@ -53,8 +53,8 @@ void WorldStateSerializerBehavior::processEvent(const EventBase& /*e*/) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/11 01:45:36 $
  */
