@@ -18,12 +18,12 @@ public:
 	virtual void DoStart(); //!< starts listening for sensor update events
 	virtual void DoStop(); //!< stops listening for events
 	virtual void processEvent(const EventBase& e); //!< core functionality - performs serialization, sends to sockets
-	virtual std::string getName() const { return "World State Serializer"; }
 	static std::string getClassDescription() {
 		char tmp[80];
 		sprintf(tmp,"Sends sensor information to port %d and current pid values to port %d",config->main.wsjoints_port,config->main.wspids_port);
 		return tmp;
 	}
+	virtual std::string getDescription() const { return getClassDescription(); }
 
 protected:
 	//! writes @a value to @a dst and advances @a dst
@@ -55,10 +55,10 @@ private:
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2004/02/05 23:33:41 $
+ * $Date: 2004/11/11 01:45:36 $
  */
 
 #endif
