@@ -20,9 +20,9 @@
 class GroupNode : public StateNode {
 public:
 	//!constructor
-	GroupNode() : StateNode("GroupNode") {}
+	GroupNode() : StateNode("GroupNode","GroupNode") {}
 	//!constructor
-	explicit GroupNode(const std::string& nm, StateNode* p=NULL) : StateNode(nm,p) {}
+	explicit GroupNode(const std::string& nm, StateNode* p=NULL) : StateNode("GroupNode",nm,p) {}
 
 	//! activates all of the sub nodes
 	virtual void DoStart() {
@@ -42,10 +42,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
