@@ -15,7 +15,7 @@ protected:
 public:
   //! constructor
   HeadPointerNode(std::string nodename="HeadPointerNode") : 
-    StateNode(nodename), head_mc(), head_id(MotionManager::invalid_MC_ID) {}
+    StateNode("HeadPointerNode",nodename), head_mc(), head_id(MotionManager::invalid_MC_ID) {}
 
   //! activate the node
   virtual void DoStart() {
@@ -34,7 +34,7 @@ public:
 
   //! receive motmanEGID status event and throw stateMachineEGID status event
   virtual void processEvent(const EventBase&) {
-    erouter->postEvent(EventBase::stateMachineEGID,(unsigned int)this,EventBase::statusETID,0);
+		erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::statusETID,0,getName(),1);
   }
 
   //! reveal the MotionCommand
@@ -43,6 +43,11 @@ public:
   //! reveal the MC_ID
   MotionManager::MC_ID& getMC_ID() { return head_id; }
 
+protected:
+  //! constructor
+  HeadPointerNode(std::string &classname, std::string &nodename) : 
+    StateNode(classname,nodename), head_mc(), head_id(MotionManager::invalid_MC_ID) {}
+
 
 };
 
@@ -50,11 +55,11 @@ public:
  * @brief Defines HeadPointerNode, a simple StateNode that runs a HeadPointerMC motion command and throws a status event upon completion
  * @author dst (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.2 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/17 01:31:06 $
  */
 
 #endif
