@@ -9,14 +9,12 @@
 //! A very simple StateNode that outputs its name to a given ostream upon activation, handy for debugging
 class OutputNode : public StateNode {
 public:
-	//!constructor, uses cout for output
-	OutputNode() : StateNode(), next(NULL), out(cout), msg() {}
 	//!constructor, sets name and ostream to use for output
-	OutputNode(const char* nm, StateNode* par, ostream& output) : StateNode(nm,par), next(NULL), out(output), msg(nm) {}
+	OutputNode(const char* nm, StateNode* par, ostream& output) : StateNode("OutputNode",nm,par), next(NULL), out(output), msg(nm) {}
 	//!constructor, sets name and another state which will immediately be transitioned to upon activation
-	OutputNode(const char* nm, StateNode* par, ostream& output, StateNode * nextstate) : StateNode(nm,par), next(nextstate), out(output), msg(nm) {}
+	OutputNode(const char* nm, StateNode* par, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm,par), next(nextstate), out(output), msg(nm) {}
 	//!constructor, sets name, message, and another state which will immediately be transitioned to upon activation
-	OutputNode(const char* nm, const std::string& mg, StateNode* par, ostream& output, StateNode * nextstate) : StateNode(nm,par), next(nextstate), out(output), msg(mg) {}
+	OutputNode(const char* nm, const std::string& mg, StateNode* par, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm,par), next(nextstate), out(output), msg(mg) {}
 
 	//!outputs this state's name, will transition to #next if non-NULL
 	/*!if #next is NULL, the state will simply stay active until some other transition causes it to leave*/
@@ -44,10 +42,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/26 03:09:10 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2004/11/11 20:35:00 $
  */
 
 #endif
