@@ -14,12 +14,12 @@ class PlayMotionSequenceNode : public StateNode {
 public:
 	//!constructor
 	PlayMotionSequenceNode()
-		: StateNode("PlayMotionSequenceNode"), msid(MotionManager::invalid_MC_ID), msidIsMine(false), looping(false), filename()
+		: StateNode("PlayMotionSequenceNode","PlayMotionSequenceNode"), msid(MotionManager::invalid_MC_ID), msidIsMine(false), looping(false), filename()
 	{}
 
 	//!constructor
 	PlayMotionSequenceNode(const std::string& nm, StateNode* par, const std::string& file, bool loop=false)
-		: StateNode(nm,par), msid(MotionManager::invalid_MC_ID), msidIsMine(false), looping(false), filename(file)
+		: StateNode("PlayMotionSequenceNode",nm,par), msid(MotionManager::invalid_MC_ID), msidIsMine(false), looping(false), filename(file)
 	{
 		setLooping(loop);
 	}
@@ -78,7 +78,7 @@ public:
 			if(looping) {
 				updateMS(filename);
 			}
-			erouter->postEvent(EventBase::stateMachineEGID,(unsigned int)this,EventBase::statusETID,0);
+			erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::statusETID,0,getName(),1);
 		}
 	}
 
@@ -120,10 +120,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/11 21:32:14 $
  */
 
 #endif
