@@ -15,7 +15,7 @@ protected:
 public:
   //! constructor
   SoundNode(std::string nodename="SoundNode", std::string soundfilename="") : 
-    StateNode(nodename), filename(soundfilename), curplay_id(SoundManager::invalid_Play_ID) {}
+    StateNode("SoundNode",nodename), filename(soundfilename), curplay_id(SoundManager::invalid_Play_ID) {}
 
   //! activate the node
   virtual void DoStart() {
@@ -32,7 +32,7 @@ public:
 
   //! receive audioEGID status event and throw stateMachineEGID status event
   virtual void processEvent(const EventBase&) {
-    erouter->postEvent(EventBase::stateMachineEGID,(unsigned int)this,EventBase::statusETID,0);
+		erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::statusETID,0,getName(),1);
   }
 
   //! interrupts playing of the current sound
@@ -47,6 +47,13 @@ public:
   //! sets the name of the sound file associated with this node
   void setFileName(std::string &soundfilename) { filename = soundfilename; }
 
+protected:
+  //! constructor
+  SoundNode(std::string &classname, std::string &nodename, std::string &soundfilename) : 
+    StateNode(classname,nodename), filename(soundfilename), curplay_id(SoundManager::invalid_Play_ID) {}
+
+
+
 };
 
 /*! @file
@@ -54,10 +61,10 @@ public:
  * @author dst (Creator)
  *
  * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/10/08 00:08:47 $
+ * $Date: 2004/11/17 01:31:06 $
  */
 
 #endif
