@@ -2,6 +2,9 @@
 #include "Events/EventRouter.h"
 #include "Wireless/Wireless.h"
 
+/*! @deprecated, behavior constructors should take a name argument (which by default should be the name of the type of the class) */
+StateNode::StateNode() : BehaviorBase("StateNode"), parent(NULL), transitions(), issetup(false), retain(true), nodes() {}
+
 StateNode::~StateNode() {
 	ASSERT(!isActive(), "Destructing while active?")
 	for(std::vector<Transition*>::iterator it=transitions.begin(); it!=transitions.end(); it++)
@@ -27,16 +30,18 @@ StateNode* StateNode::addNode(StateNode* node) {
 }
 
 void StateNode::DoStart() {
-	BehaviorBase::DoStart();
-	if(!issetup) {
-		setup();
-		issetup=true;
-	}
-	for(std::vector<Transition*>::iterator it=transitions.begin(); it!=transitions.end(); it++)
-	  if ( !(*it)->isActive()  ) (*it)->DoStart();
-	erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::activateETID,0,getName(),1);
-	if(parent!=NULL)
-		parent->transitionTo(this);
+  if ( parent == NULL && transitions.size() > 0 )
+    serr->printf("Warning! StateNode '%s' has transitions but no parent; you probably forgot to call addNode().\n",getName().c_str());
+  BehaviorBase::DoStart();
+  if(!issetup) {
+    setup();
+    issetup=true;
+  }
+  for(std::vector<Transition*>::iterator it=transitions.begin(); it!=transitions.end(); it++)
+    if ( !(*it)->isActive()  ) (*it)->DoStart();
+  erouter->postEvent(EventBase::stateMachineEGID,reinterpret_cast<unsigned int>(this),EventBase::activateETID,0,getName(),1);
+  if(parent!=NULL)
+    parent->transitionTo(this);
 }
 
 void StateNode::DoStop() {
@@ -58,10 +63,6 @@ void StateNode::DoStop() {
 	BehaviorBase::DoStop();
 }
 
-void StateNode::setName(const std::string& n) {
-	name=n;
-}
-
 void StateNode::transitionTo(StateNode*) {
 	// may want to throw a status event here
 }
@@ -74,10 +75,10 @@ void StateNode::transitionFrom(StateNode*) {
  * @brief Describes StateNode, which is both a state machine controller as well as a node within a state machine itself
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.17 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/10/04 22:57:56 $
+ * $Date: 2004/11/11 01:45:31 $
  */
 
