@@ -11,13 +11,11 @@
 /*! Override setup() to setup your own Transition and StateNode network.*/
 class StateNode  : public BehaviorBase {
 public:
-	//!constructor
-	StateNode() : BehaviorBase(), parent(NULL), transitions(), issetup(false), retain(true), nodes(), name("?") {	/*std::cout << "!" << std::endl;*/ }
+	//! deprecated, behavior constructors should take a name argument (which by default should be the name of the type of the class)
+	StateNode() __attribute__((deprecated));
 
-	//!constructor, pass a name to use, calls setName(n) 
-	StateNode(const std::string& n, StateNode* p=NULL) : BehaviorBase(), parent(p), transitions(), issetup(false), retain(true), nodes(), name("") {
-		setName(n);
-	}
+	//!constructor, pass a name to use and the parent node if applicable (usually 'this' within setup())
+	StateNode(const std::string& name, StateNode* p=NULL) : BehaviorBase("StateNode",name), parent(p), transitions(), issetup(false), retain(true), nodes() {}
 
 	//!destructor, removes references to its outgoing transitions (be careful of incoming ones - they're still around!), and calls RemoveReference() on subnodes
 	virtual ~StateNode();
@@ -49,16 +47,10 @@ public:
 	//!This is called by DoStop() when you should destruct subnodes
 	virtual void teardown() { issetup=false; /*std::cout << "Teardown!!!!!!!!" << std::endl;*/ }
 
-	//!set name to @a n.  Makes a copy of @a n, so you can throw it away later.
-	void setName(const std::string& n);
-
-	//!returns name of StateNode
-	virtual std::string getName() const { return name; }
-
-	//!returns name again (you should override this for top-level nodes to give users better descriptions)
-	virtual std::string getDescription() const { return name; }
-
 protected:
+	//!constructor, pass a name to use and the parent node if applicable (usually 'this' within setup())
+	StateNode(const std::string& classname, const std::string& name, StateNode* p=NULL) : BehaviorBase(classname,name), parent(p), transitions(), issetup(false), retain(true), nodes() {}
+
 	//!called by a subnode when it is being DoStart()'ed
 	virtual void transitionTo(StateNode* n);
 
@@ -79,10 +71,6 @@ protected:
 	//! vector of StateNodes, just so they can be dereferenced again on DoStop() (unless retained) or ~StateNode()
 	std::vector<StateNode*> nodes;
 
-	//Behavior Stuff:
-	//! holds the name of the Node/Machine
-	std::string name;
-
 private:
 	StateNode(const StateNode& node); //!< don't call this
 	StateNode operator=(const StateNode& node); //!< don't call this
@@ -92,11 +80,11 @@ private:
  * @brief Describes StateNode, which is both a state machine controller as well as a node within a state machine itself
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.10 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/10/04 22:57:56 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
