@@ -3,7 +3,6 @@
 #define INCLUDED_Transition_h_
 
 #include "BehaviorBase.h"
-#include "Wireless/Socket.h"
 #include <vector>
 
 class StateNode;
@@ -36,29 +35,14 @@ class StateNode;
 class Transition : public BehaviorBase {
 	friend class StateNode;
 public:
-	//!constructor
-	Transition() : BehaviorBase(), srcs(), dsts(), sound() {}
-	//!constructor, specify destination StateNode (ignores NULL)
-	Transition(StateNode* destination) : BehaviorBase(), srcs(), dsts(), sound() {
-		addDestination(destination);
-	}
-	//!copy constructor, just in case you need it
-	Transition(const Transition& t) : BehaviorBase(t), srcs(t.srcs), dsts(t.dsts), sound(t.sound) {}
-
-	//!assignment operator (only does shallow copy)
-	Transition& operator=(const Transition& t) { BehaviorBase::operator=(t); srcs=t.srcs; dsts=t.dsts; sound=t.sound; return *this; }
-
 	//!destructor
 	virtual ~Transition() {}
 
 	//!call this when the transition should be made, base class version simply calls StateNode::DoStop() on each active of #srcs and StateNode::DoStart() on each inactive of #dsts, but you can override.
 	virtual void fire();
 
-  //!deprecated: use #fire() instead
-  virtual void activate() {
-    serr->printf("Transition::activate() is deprecated.  Use Transition::fire() instead.\n");
-    fire();
-  }
+  //!deprecated: use #fire() instead (just a better name
+  virtual void activate() __attribute__((deprecated));
 
 	virtual std::vector<StateNode*>& getSources() { return srcs; }  //!< returns a user-modifiable reference to the current source list
 	virtual const std::vector<StateNode*>& getSources() const { return srcs; } //!< returns a const reference to the current source list
@@ -70,7 +54,32 @@ public:
 	virtual void setSound(const std::string& snd) { sound=snd; } //!< set a sound file to be played upon activation; you might want to preload this in the parent node; empty string to turn off
 	virtual std::string getSound() { return sound; } //!< returns the current sound file
 	
+	//! If #instanceName == #className, will autogenerate a name incorporating source and destination names
+	virtual std::string getName() const;
+
 protected:
+	//! deprecated, use the version of the constructor where you can pass a name
+	Transition() __attribute__((deprecated));
+	//!constructor, pass your subclass type name as a string for the default name
+	explicit Transition(const std::string& classname) : BehaviorBase(classname), srcs(), dsts(), sound() {}
+	//! deprecated, use the version of the constructor where you can pass a name
+	explicit Transition(StateNode* destination) __attribute__((deprecated));
+	//!constructor, specify destination StateNode (ignores NULL)
+	Transition(const std::string& classname, StateNode* destination) : BehaviorBase(classname), srcs(), dsts(), sound() {
+		addDestination(destination);
+	}
+	//!constructor, pass your subclass type name as a string for the default name, and a separate instance name
+	Transition(const std::string& classname, const std::string& instancename) : BehaviorBase(classname,instancename), srcs(), dsts(), sound() {}
+	//!constructor, specify names and destination StateNode (ignores NULL)
+	Transition(const std::string& classname, const std::string& instancename, StateNode* destination) : BehaviorBase(classname,instancename), srcs(), dsts(), sound() {
+		addDestination(destination);
+	}
+	//!copy constructor, just in case you need it
+	Transition(const Transition& t) : BehaviorBase(t), srcs(t.srcs), dsts(t.dsts), sound(t.sound) {}
+
+	//!assignment operator (only does shallow copy)
+	Transition& operator=(const Transition& t) { BehaviorBase::operator=(t); srcs=t.srcs; dsts=t.dsts; sound=t.sound; return *this; }
+
 	//! if @a source is non-null, add it to the source list
 	/*! Only StateNodes should be calling this - you add a transition to a source, not a source to a transition.
 	 *  @see StateNode::addTransition() */
@@ -85,11 +94,11 @@ protected:
  * @brief Describes Transition, represents a transition between StateNodes.
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/10/04 22:59:57 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
