@@ -36,7 +36,12 @@ public:
 	
 	//! constructor, see CompareTrans class notes for information
   CompareTrans(StateNode* destination, const T* monitor, Test_t test, const T& value, const EventBase& poll)
-		: Transition(destination), mon(monitor), tst(test), val(value), poller(poll)
+		: Transition("CompareTrans",destination), mon(monitor), tst(test), val(value), poller(poll)
+	{ }
+	
+	//! constructor, see CompareTrans class notes for information
+  CompareTrans(const std::string& name, StateNode* destination, const T* monitor, Test_t test, const T& value, const EventBase& poll)
+		: Transition("CompareTrans",name,destination), mon(monitor), tst(test), val(value), poller(poll)
 	{ }
 	
 	//!starts listening
@@ -69,9 +74,12 @@ public:
 		}
 	}
 
-	virtual std::string getName() const { return "CompareTrans"; }
-
 protected:
+	//! constructor, see CompareTrans class notes for information (this version is only need by subclasses so they can pass their type name)
+  CompareTrans(const std::string& classname, const std::string& instancename, StateNode* destination, const T* monitor, Test_t test, const T& value, const EventBase& poll)
+		: Transition(classname,instancename,destination), mon(monitor), tst(test), val(value), poller(poll)
+	{ }
+
 	const T* mon; //!< address of value to monitor
 	Test_t tst; //!< test to make
 	T val; //!< value to compare against
@@ -87,10 +95,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
