@@ -14,7 +14,10 @@ protected:
 
 public:
   CompletionTrans(StateNode* destination, int n=0) :
-    Transition(destination), minsrcs(n), completions(NULL) {};
+    Transition("CompletionTrans",destination), minsrcs(n), completions(NULL) {};
+
+  CompletionTrans(const std::string& name, StateNode* destination, int n=0) :
+    Transition("CompletionTrans",name,destination), minsrcs(n), completions(NULL) {};
 
   //! starts listening
   virtual void DoStart() {
@@ -50,9 +53,11 @@ public:
     if (numcomplete >= threshold) fire();
   }
 
-  virtual std::string getName() const { return "CompletionTrans"; }
-
 protected:
+	//!constructor, this version is only need by subclasses so they can pass their type name
+  CompletionTrans(const std::string& classname, const std::string& instancename, StateNode* destination, int n=0) :
+    Transition(classname,instancename,destination), minsrcs(n), completions(NULL) {};
+
   //!@name Dummy functions to satisfy the compiler
   CompletionTrans(const CompletionTrans&);  //!< don't call this
   CompletionTrans& operator=(const CompletionTrans&);  //!< don't call this
@@ -65,10 +70,10 @@ protected:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
