@@ -9,7 +9,10 @@
 class NullTrans : public Transition {
 public:
   //! constructor
-  NullTrans(StateNode* destination) : Transition(destination) {}
+  NullTrans(StateNode* destination) : Transition("NullTrans",destination) {}
+	
+  //! constructor
+  NullTrans(const std::string& name, StateNode* destination) : Transition("NullTrans",name,destination) {}
 	
   //!starts 0 msec timer, so transition will occur very soon
   virtual void DoStart() {
@@ -22,9 +25,6 @@ public:
 
   //!when timer event is received, fire() the transition
   virtual void processEvent(const EventBase&) { fire(); }
-
-  virtual std::string getName() const { return "TimeOutTrans"; }
-
 };
 
 /*! @file
@@ -32,10 +32,10 @@ public:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
