@@ -16,7 +16,13 @@ class SmoothCompareTrans : public CompareTrans<T> {
 public:
 	//! constructor, see SmoothCompareTrans class notes for information
   SmoothCompareTrans(StateNode* destination, const T* monitor, typename SmoothCompareTrans<T>::Test_t test, const T& value, const EventBase& poll, float gammap=0)
-		: CompareTrans<T>(destination,&avg,test,value,poll), avg(*monitor), realmon(monitor),
+		: CompareTrans<T>("SmoothCompareTrans",destination,&avg,test,value,poll), avg(*monitor), realmon(monitor),
+		burnin((unsigned int)(1/(1-gammap))), tests(0), g(gammap)
+	{ }
+
+	//! constructor, see SmoothCompareTrans class notes for information
+  SmoothCompareTrans(const std::string& name, StateNode* destination, const T* monitor, typename SmoothCompareTrans<T>::Test_t test, const T& value, const EventBase& poll, float gammap=0)
+		: CompareTrans<T>("SmoothCompareTrans",name,destination,&avg,test,value,poll), avg(*monitor), realmon(monitor),
 		burnin((unsigned int)(1/(1-gammap))), tests(0), g(gammap)
 	{ }
 
@@ -47,8 +53,6 @@ public:
 			CompareTrans<T>::processEvent(e);
 	}
 
-	virtual std::string getName() const { return "SmoothCompareTrans"; }
-
 protected:
 	T avg; //!< the current running average
 	const T* realmon; //!< pointer to the value being monitored
@@ -69,10 +73,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2003/11/11 00:08:18 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
