@@ -9,7 +9,10 @@
 class TimeOutTrans : public Transition {
 public:
   //! constructor, specify delay in milliseconds
-  TimeOutTrans(StateNode* destination, unsigned int delay) : Transition(destination), d(delay) {}
+  TimeOutTrans(StateNode* destination, unsigned int delay) : Transition("TimeOutTrans",destination), d(delay) {}
+
+  //! constructor, specify delay in milliseconds
+  TimeOutTrans(const std::string& name, StateNode* destination, unsigned int delay) : Transition("TimeOutTrans",name,destination), d(delay) {}
 
   //!starts timer
   virtual void DoStart() {
@@ -32,9 +35,10 @@ public:
     fire();
   }
 
-  virtual std::string getName() const { return "TimeOutTrans"; }
-
 protected:
+  //! constructor, specify delay in milliseconds
+  TimeOutTrans(const std::string& classname, const std::string& instancename, StateNode* destination, unsigned int delay) : Transition(classname,instancename,destination), d(delay) {}
+
   //!amount to delay (in milliseconds) before transition
   unsigned int d;
 };
@@ -44,10 +48,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
