@@ -14,7 +14,10 @@
 class VisualTargetCloseTrans : public Transition {
 public:
 	//!constructor
-	VisualTargetCloseTrans(StateNode* destination, unsigned int source_id) : Transition(destination), sid(source_id) {}
+	VisualTargetCloseTrans(StateNode* destination, unsigned int source_id) : Transition("VisualTargetCloseTrans",destination), sid(source_id) {}
+
+	//!constructor
+	VisualTargetCloseTrans(const std::string& name, StateNode* destination, unsigned int source_id) : Transition("VisualTargetCloseTrans",name,destination), sid(source_id) {}
 
 	//!starts listening for the object specified by the source id in the constructor
 	virtual void DoStart() { Transition::DoStart(); erouter->addListener(this,EventBase::visObjEGID,sid); }
@@ -41,8 +44,6 @@ public:
 			fire();
 	}
 
-	virtual std::string getName() const { return "VisualTargetCloseTrans"; }
-
 protected:
 	//!Source ID of object to track
 	unsigned int sid;
@@ -53,10 +54,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
