@@ -12,7 +12,11 @@ class VisualTargetTrans : public Transition {
 public:
 	//!constructor
 	VisualTargetTrans(StateNode* destination, unsigned int source_id)
-		: Transition(destination), sid(source_id), count(0) {}
+		: Transition("VisualTargetTrans",destination), sid(source_id), count(0) {}
+
+	//!constructor
+	VisualTargetTrans(const std::string& name, StateNode* destination, unsigned int source_id)
+		: Transition("VisualTargetTrans",name,destination), sid(source_id), count(0) {}
 
 	//!starts listening for the object specified by the source id in the constructor
 	virtual void DoStart() {
@@ -46,8 +50,6 @@ public:
 		//serr->printf("VisualTargetTrans::processEvent() - leave %d\n",get_time());
 	}
 
-	virtual std::string getName() const { return "VisualTargetTrans"; }
-
 protected:
 	//!Source ID of object to track
 	unsigned int sid;
@@ -60,10 +62,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/10/07 19:07:05 $
+ * $Date: 2004/11/15 22:46:19 $
  */
 
 #endif
