@@ -22,14 +22,11 @@ class EventGeneratorBase : public BehaviorBase {
 public:
 	//!@name Constructors
 	//!
-	EventGeneratorBase()
-		: BehaviorBase(), myGenID(EventBase::unknownEGID), mySourceID(0), autoListen(false), srcGenID(EventBase::unknownEGID), srcSourceID(0), myName()
-	{}
 	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid)
-		: BehaviorBase(), myGenID(mgid), mySourceID(msid), autoListen(false), srcGenID(EventBase::unknownEGID), srcSourceID(0), myName(name)
+		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(false), isListening(false), srcGenID(EventBase::unknownEGID), srcSourceID(0)
 	{}
 	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid)
-		: BehaviorBase(), myGenID(mgid), mySourceID(msid), autoListen(true), srcGenID(srcgid), srcSourceID(srcsid), myName(name)
+		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(true), isListening(false), srcGenID(srcgid), srcSourceID(srcsid)
 	{}
 	//@}
 
@@ -40,6 +37,13 @@ public:
 	
 	virtual void DoStop();
 	
+	//! if autolistening, will receive EventRouter events concerning our own listeners
+	/*! This will automatically reduce overhead by eliminating chains of events thrown
+	 *  that don't have any end listeners.  However, this might mean your subclass's
+	 *  processEvent will be receiving the events from erouterEGID, and will need
+	 *  to call EventGeneratorBase::processEvent() in order to allow them to be used */
+	virtual void processEvent(const EventBase& event);
+	
 	//! return the generator ID that will be broadcast from
 	virtual EventBase::EventGeneratorID_t getGeneratorID() { return myGenID; }
 	//! set the generator ID that will be broadcast from (typically it's a bad idea to call this...)
@@ -55,28 +59,18 @@ public:
 	//! returns the generator ID that will be listened for (not the generator of the FilterBankEvent to be created - that depends on the subclass)
 	virtual EventBase::EventGeneratorID_t getListenGeneratorID() const { return srcGenID; }
 	//! turns on auto listening to make it easier to set up dependancies between vision filters
-	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid) { autoListen=true; srcGenID=gid; srcSourceID=sid; }
+	virtual void setAutoListen(EventBase::EventGeneratorID_t gid, unsigned int sid);
 
 	//! turns off auto listening
-	virtual void unsetAutoListen() { autoListen=false; }
-
-	//! returns current name
-	virtual std::string getName() const {
-		return myName;
-	}
-
-	//! sets a name (overriding automatically generated one)
-	virtual void setName(const std::string& name) {
-		myName=name;
-	}
+	virtual void unsetAutoListen();
 
 protected:
 	EventBase::EventGeneratorID_t myGenID; //!< the generator ID to broadcast on
 	unsigned int mySourceID;     //!< the source ID to broadcast on
 	bool autoListen;          //!< if true, will automatically start listening for EventBase(genID,sourceID) events
+	bool isListening;         //!< true if listening triggered by autoListen
 	EventBase::EventGeneratorID_t srcGenID; //!< the generator ID to listen for (typically the source that this filter works on)
 	unsigned int srcSourceID;    //!< the source ID to listen for
-	std::string myName;  //!< the name to report (handy for debugging output)
 };
 
 /*! @file
@@ -84,10 +78,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/18 21:12:18 $
+ * $Date: 2004/11/11 01:45:37 $
  */
 
 #endif
