@@ -366,7 +366,7 @@ MMCombo::ReadySendJoints(const OReadyEvent& sysevent) {
 	if(state!=NULL)
 		isERS7=state->robotDesign&WorldState::ERS7Mask;
 	else {
-		char robotDesignStr[orobotdesignNAME_MAX];
+		char robotDesignStr[orobotdesignNAME_MAX + 1];
 		memset(robotDesignStr, 0, sizeof(robotDesignStr));
 		if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
 			cout << objectName << "::SetupOutputs - OPENR::GetRobotDesign() failed." << endl;
@@ -387,12 +387,13 @@ MMCombo::ReadySendJoints(const OReadyEvent& sysevent) {
 		}
 			
 		// Should be a relatively simple matter to copy angles into commands...
-		unsigned int used=0; //but only copy open joints (so main does ears, motion does everything else)
+		unsigned int used=0; //but only copy open joints (so main does ears on 210, motion does everything else)
 		for(unsigned int i=PIDJointOffset; i<PIDJointOffset+NumPIDJoints; i++)
 			if(open[i]) {
+				float cal=config->motion.calibration[i-PIDJointOffset];
 				OJointCommandValue2* jval = reinterpret_cast<OJointCommandValue2*>(cmdVecData->GetData(used)->value);
 				for(unsigned int frame=0; frame<NumFrames; frame++)
-					jval[frame].value = (slongword)(outputs[frame][i]*1e6);
+					jval[frame].value = (slongword)(outputs[frame][i]*1e6*cal);
 				used++;
 			}
 		if(isERS7) {
@@ -534,9 +535,10 @@ MMCombo::GotAudio(const ONotifyEvent& event){
 	PROFSECTION("GotAudio()",state->mainProfile);
 	etrans.translateEvents();
 
-	erouter->postEvent(new DataEvent<const OSoundVectorData*>(reinterpret_cast<const OSoundVectorData*>(event.Data(0)),EventBase::micOSndEGID,0,EventBase::statusETID));
-	
-  erouter->processTimers();
+	for (int i = 0; i < event.NumOfData(); i++) {
+		erouter->postEvent(new DataEvent<const OSoundVectorData*>(reinterpret_cast<const OSoundVectorData*>(event.Data(i)),EventBase::micOSndEGID,0,EventBase::statusETID));
+		erouter->processTimers();
+	}
   
   observer[obsMic]->AssertReady();
 }
@@ -616,7 +618,7 @@ MMCombo::OpenPrimitives()
 void
 MMCombo::SetupOutputs(const bool to_open[NumOutputs])
 {
-	char robotDesignStr[orobotdesignNAME_MAX];
+	char robotDesignStr[orobotdesignNAME_MAX + 1];
 	memset(robotDesignStr, 0, sizeof(robotDesignStr));
 	if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
 		cout << objectName << "::SetupOutputs - OPENR::GetRobotDesign() failed." << endl;
@@ -767,10 +769,10 @@ MMCombo::RPOPENR_send(char *buf, int bufsize) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.57 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.60 $
  * $State: Exp $
- * $Date: 2004/10/11 22:00:19 $
+ * $Date: 2004/11/12 22:07:39 $
  */
 
 
