@@ -321,6 +321,11 @@ Kinematics::findUnusedLeg(const NEWMAT::ColumnVector& down) {
 	return static_cast<LegOrder_t>(highleg);
 }
 
+NEWMAT::ReturnMatrix
+Kinematics::calculateGroundPlane() {
+  return calculateGroundPlane(pack(state->sensors[BAccelOffset],state->sensors[LAccelOffset],state->sensors[DAccelOffset]));
+}
+
 NEWMAT::ReturnMatrix
 Kinematics::calculateGroundPlane(const NEWMAT::ColumnVector& down) {
 	//Find the unused foot
@@ -405,10 +410,10 @@ Kinematics::update(unsigned int c, unsigned int l) {
  * @brief 
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.18 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:10 $
+ * $Date: 2004/10/28 23:06:10 $
  */
 
