@@ -75,7 +75,7 @@ class LedEngine {
 	void flash(LEDBitMask_t leds, unsigned int ms);
 	//!causes the leds specified by @a leds to cycle between low and high, clears others.  See cycle() for parameter documentation.
 	inline void ccycle(LEDBitMask_t leds, unsigned int period, float amp, float offset=0, int phase=0) { clear(); cycle(leds,period,amp,offset,phase); }
-	//!causes the leds specified by @a leds to cycle between low and high
+	//!causes the leds specified by @a leds to cycle between low and high; values calculated for cycle will be clipped to [0,1] for more sensible blending of square wave approximations (high amplitude sine wave)
 	void cycle(LEDBitMask_t leds, unsigned int period, float amp, float offset=0, int phase=0);
 	//!sets all leds to 0.
 	void clear();
@@ -134,6 +134,10 @@ class LedEngine {
 	static float calcCycle(unsigned int period, float amp, float offset, unsigned int t) {
 		//		cout << period << ',' << amp << ',' << offset << ',' << time << " -> " << x;
 		float x=cos(t*6.2831853/period)*(-amp/2)+.5+offset;
+		if(x<0)
+			return 0;
+		if(x>1)
+			return 1;
 		return x;
 	}
 	//!Calculates the current value of led @a i for current time t
@@ -172,11 +176,11 @@ class LedEngine {
  * @brief Describes LedEngine, which provides basic LED effects to anything that inherits or instantiates it
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.17 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2004/09/12 04:22:37 $
+ * $Date: 2004/11/16 00:29:47 $
  */
 
 #endif
