@@ -197,7 +197,7 @@ unsigned int MotionSequence::LoadBuffer(const char buf[], unsigned int len) {
 }
 
 unsigned int MotionSequence::SaveBuffer(char buf[], unsigned int len) const {
-	std::cout << "SAVEBUFFER..." << std::flush;
+	//std::cout << "SAVEBUFFER..." << std::flush;
 	unsigned int origlen=len;
 	int written=snprintf(buf,len,"#MSq\n");
 	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequence save failed on header\n")) return 0;	if(len==0 || len>origlen) {
@@ -434,9 +434,9 @@ unsigned int MotionSequence::getOutputIndex(const char name[], unsigned int idx)
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2004/10/14 23:02:53 $
+ * $Date: 2004/11/08 21:48:19 $
  */
 
