@@ -180,6 +180,7 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 			}
 		}
 		written=-1;
+		jname[0]='\0';
 		sscanf(buf,formatstring,jname,&fval,&fwht,&written);
 		if(!ChkAdvance(written,&buf,&len,"*** ERROR PostureEngine load corrupted - line %d\n",linenum)) return 0;
 		while(*buf!='\n' && *buf!='\r')
@@ -190,20 +191,22 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 			buf++;
 		linenum++;
 		//std::cout << '"' << jname << "\"\t" << (float)fval << '\t' << (float)fwht << std::endl;
-		unsigned int startidx=idx+1;
+		// we continue the search in order from where we left off - these are often
+		// going to go in order, so might as well save a little time
+		unsigned int startidx=idx;
 		for(;idx<NumOutputs;idx++)
 			if(strcmp(jname,outputNames[idx])==0) {
 				cmds[idx].set(fval,fwht);
 				break;
 			}
-		if(idx==NumOutputs) {
+		if(idx==NumOutputs) { //not found following startidx, look from beginning
 			for(idx=0;idx<startidx;idx++)
 				if(strcmp(jname,outputNames[idx])==0) {
 					cmds[idx].set(fval,fwht);
 					break;
 			}
-			if(idx==startidx && strcmp(jname,outputNames[idx])!=0)
-				std::cout << "*** WARNING " << jname << " is not a valid joint on this model." << std::endl;
+			if(idx==startidx && strcmp(jname,outputNames[idx])!=0) //not found at all
+				std::cout << "*** WARNING '" << jname << "' is not a valid joint on this model." << std::endl;
 		}
 	}
 	std::cout << "*** WARNING PostureEngine load missing #END" << std::endl;
@@ -330,9 +333,9 @@ PostureEngine::update(unsigned int c, unsigned int l) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.21 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.22 $
  * $State: Exp $
- * $Date: 2004/10/18 19:53:33 $
+ * $Date: 2004/11/15 21:43:54 $
  */
 
