@@ -12,16 +12,25 @@
 class TailWagMC : public MotionCommand {
  public:
 	//!constructor
-	TailWagMC() : period(500), magnitude(22*3.141592/180), active(false), tilt() { }
+	TailWagMC() : period(500), magnitude(22*M_PI/180), active(true), tilt() { }
+	TailWagMC(unsigned int cyc_period, float cyc_magnitude) : period(cyc_period), magnitude(cyc_magnitude), active(true), tilt() { }
 	//!destructor
 	virtual ~TailWagMC() {}
 	virtual int updateOutputs() {
-		if(active && state->robotDesign&WorldState::ERS210Mask) {
+		if(!active)
+			return 0;
+		if(state->robotDesign&WorldState::ERS210Mask) {
 			for(unsigned int i=0; i<NumFrames; i++)
-				pans[i].set(sin((2*M_PI*(get_time()+i*FrameTime))/period)*magnitude); //bug fix thanks L.A.Olsson@herts.ac.uk
+				pans[i].set(sin((2*M_PI*(get_time()+i*FrameTime))/period)*magnitude); //bug fix thanks L.A.Olsson AT herts ac uk
 			motman->setOutput(this,ERS210Info::TailOffset+PanOffset,pans);
 			motman->setOutput(this,ERS210Info::TailOffset+TiltOffset,tilt);
-			return 1;
+			return tilt.weight>0?2:1;
+		} else if(state->robotDesign&WorldState::ERS7Mask) {
+			for(unsigned int i=0; i<NumFrames; i++)
+				pans[i].set(sin((2*M_PI*(get_time()+i*FrameTime))/period)*magnitude); //bug fix thanks L.A.Olsson AT herts ac uk
+			motman->setOutput(this,ERS7Info::TailOffset+PanOffset,pans);
+			motman->setOutput(this,ERS7Info::TailOffset+TiltOffset,tilt);
+			return tilt.weight>0?2:1;
 		} else
 			return 0;
 	}
@@ -51,10 +60,10 @@ class TailWagMC : public MotionCommand {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:23 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
+ * $State: Exp $
+ * $Date: 2004/11/15 22:22:36 $
  */
 
 #endif
