@@ -3,7 +3,9 @@
 #include "Vision/RawCameraGenerator.h"
 #include <stdio.h>
 #include <string>
+#include <cstring>
 #include <ctype.h>
+#include "Wireless/Socket.h"
 #ifdef PLATFORM_APERIOS
 #  include <OPENR/OPrimitiveControl.h>
 #  include <OPENR/OPENRAPI.h>
@@ -287,6 +289,14 @@ void* Config::setValue(section_t section, const char *key, const char *value,
       } else if (strncasecmp(key,"kinematic_chains",29)==0) {
 				motion.kinematic_chains.push_back(value);
         return &motion.kinematic_chains;
+      } else if (strncasecmp(key,"calibrate:",10)==0) {
+				for(unsigned int i=PIDJointOffset; i<PIDJointOffset+NumPIDJoints; i++)
+					if(strncasecmp(&key[10],outputNames[i],outputNameLen+1)==0) { //+1 to ensure full match
+						motion.calibration[i-PIDJointOffset] = atof(value);
+						return &motion.calibration[i];
+					}
+				std::cout << "WARNING: Could not match '" << (strlen(key)>10?&key[10]:key) << "' as calibration parameter" << std::endl;
+				return NULL;
       } else if (strncasecmp(key,"estop_on_snd",29)==0) {
         strncpy(motion.estop_on_snd,value,49);
         return &motion.estop_on_snd;
@@ -335,6 +345,27 @@ void* Config::setValue(section_t section, const char *key, const char *value,
       } else if (strncasecmp(key,"preload",29)==0) {
         sound.preload.push_back(value);
         return &sound.preload ;
+      } else if (strncasecmp(key,"streaming.mic_port",29)==0) {
+        sound.streaming.mic_port = atoi(value);
+        return &sound.streaming.mic_port;
+      } else if (strncasecmp(key,"streaming.mic_sample_rate",29)==0) {
+        sound.streaming.mic_sample_rate = atoi(value);
+        return &sound.streaming.mic_sample_rate;
+      } else if (strncasecmp(key,"streaming.mic_sample_bits",29)==0) {
+        sound.streaming.mic_sample_bits = atoi(value);
+        return &sound.streaming.mic_sample_bits;
+      } else if (strncasecmp(key,"streaming.mic_stereo",29)==0) {
+        sound.streaming.mic_stereo = extractBool(value);
+        return &sound.streaming.mic_stereo;
+      } else if (strncasecmp(key,"streaming.speaker_port",29)==0) {
+        sound.streaming.speaker_port = atoi(value);
+        return &sound.streaming.speaker_port;
+      } else if (strncasecmp(key,"streaming.speaker_frame_length",30)==0) {
+        sound.streaming.speaker_frame_length = atoi(value);
+        return &sound.streaming.speaker_frame_length;
+      } else if (strncasecmp(key,"streaming.speaker_max_delay",29)==0) {
+        sound.streaming.speaker_max_delay = atoi(value);
+        return &sound.streaming.speaker_max_delay;
       }
       break;
     default:
@@ -372,7 +403,7 @@ void Config::readConfig(const char* filename) {
 	bool ignoring=false;
 	std::vector<std::string> curmodel;
 #ifdef PLATFORM_APERIOS
-	char rdStr[orobotdesignNAME_MAX];
+	char rdStr[orobotdesignNAME_MAX + 1];
 	memset(rdStr, 0, sizeof(rdStr));
 	if (OPENR::GetRobotDesign(rdStr) != oSUCCESS) {
 		printf("OPENR::GetRobotDesign() failed.\n");
@@ -499,9 +530,9 @@ bool Config::extractBool(const char * value) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.36 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2004/10/11 22:01:34 $
+ * $Date: 2004/11/12 22:07:39 $
  */
 
