@@ -147,6 +147,7 @@ class Config {
 		std::string walk;       //!< the walk parameter file to load by default for new WalkMC's
 		std::string kinematics;  //!< the kinematics description file to load
 		std::vector<std::string> kinematic_chains; //!< list of chains to load from #kinematics
+		float calibration[NumPIDJoints]; //!< multiplier from desired to command for PID joints
 		char estop_on_snd[50];  //!< sound file to use when e-stop turned on
 		char estop_off_snd[50]; //!< sound file to use when e-stop turned off
 		float max_head_tilt_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
@@ -166,11 +167,13 @@ class Config {
 		}
 
 		//!constructor
-		motion_config() : root(), walk(), kinematics(), kinematic_chains(), max_head_tilt_speed(0), max_head_pan_speed(0), max_head_roll_speed(0), console_port(0), stderr_port(0) {
+		motion_config()
+			: root(), walk(), kinematics(), kinematic_chains(), max_head_tilt_speed(0),
+				max_head_pan_speed(0), max_head_roll_speed(0), console_port(0), stderr_port(0)
+		{
 			estop_on_snd[0]=estop_off_snd[0]='\0';
-			max_head_tilt_speed=0;
-			max_head_pan_speed=0;
-			max_head_roll_speed=0;
+			for(unsigned int i=0; i<NumPIDJoints; i++)
+				calibration[i]=1;
 		}
 	} motion;
 
@@ -191,9 +194,26 @@ class Config {
 			else
 				return root+"/"+name;
 		}
+		
+		//! audio streaming configuration
+		struct streaming_config {
+		  unsigned int mic_port;        //!< port for streaming microphone samples
+			unsigned int mic_sample_rate; //!< sample rate from the microphone
+			unsigned int mic_sample_bits; //!< sample bit depth from the microphone (either 8 or 16)
+			bool mic_stereo; //!< whether to stream stereo or mono from the microphone
+      
+			unsigned int speaker_port;    //!< port for streaming speaker samples
+			unsigned int speaker_frame_length; //<! length of frame sent to the speaker (ms)
+			unsigned int speaker_max_delay; //<! maximum delay (ms) during playback
+
+			streaming_config() : mic_port(0), mic_sample_rate(16000),
+			mic_sample_bits(16), mic_stereo(true),
+			speaker_port(0), speaker_frame_length(64),
+			speaker_max_delay(1000) {}
+		} streaming;
 
 		//!constructor
-		sound_config() : root(), volume(0xF600), sample_rate(0), sample_bits(0), preload() {}
+		sound_config() : root(), volume(0xF600), sample_rate(0), sample_bits(0), preload(), streaming() {}
 	} sound;
 
 	//! call this function when it's time to read the configuration file
@@ -220,10 +240,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.35 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.37 $
  * $State: Exp $
- * $Date: 2004/10/11 22:01:34 $
+ * $Date: 2004/11/12 22:07:39 $
  */
 
 #endif
