@@ -14,8 +14,8 @@ class ReferenceCounter {
 	ReferenceCounter() : references(0),RC_autodelete(true) {}
 	//! copy constructor - uses autodelete setting of @a rc, but references will still start at 0
 	ReferenceCounter(const ReferenceCounter& rc) : references(0),RC_autodelete(rc.RC_autodelete) {}
-	//! assignment operator - does nothing
-	ReferenceCounter& operator=(const ReferenceCounter& rc) {return *this;}
+	//! assignment operator - does nothing because the reference count shouldn't be copied
+	ReferenceCounter& operator=(const ReferenceCounter& /*rc*/) {return *this;}
 
 	//! destructor - will std::cout a warning if still has references
 	virtual ~ReferenceCounter() {
@@ -73,10 +73,10 @@ const char* findname(ReferenceCounter* x) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/09 22:45:28 $
+ * $Date: 2004/11/11 20:35:00 $
  */
 
 #endif
