@@ -13,6 +13,7 @@
 #include "ERS210Info.h"
 #include "ERS220Info.h"
 #include "ERS7Info.h"
+#include "Shared/Config.h"
 
 #define GETD(cpc) (((float)sensor.GetData(cpc)->frame[lastFrame].value) / 1.0E6f) //!< returns value from OPEN-R, converted from micro in int to base in float
 #define GETB(cpc) ((bool)sensor.GetData(cpc)->frame[lastFrame].value) //!< returns value from OPEN-R, as bool
@@ -47,7 +48,7 @@ WorldState::WorldState()
 
 #ifdef PLATFORM_APERIOS
 	//Thanks Daishi:
-	char robotDesignStr[orobotdesignNAME_MAX];
+	char robotDesignStr[orobotdesignNAME_MAX + 1];
 	memset(robotDesignStr, 0, sizeof(robotDesignStr));
 	if (OPENR::GetRobotDesign(robotDesignStr) != oSUCCESS) {
 		cout << "OPENR::GetRobotDesign() failed." << endl;
@@ -296,6 +297,10 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 		sensors[DAccelOffset] = GETD(ERS7Info::CPCSensorAccelUD);
 	}
 
+	//Apply sensor calibrations (currently only joint positions - perhaps IR as well?)
+	for(unsigned int i=0; i<NumPIDJoints; i++)
+		outputs[PIDJointOffset+i]/=config->motion.calibration[i];
+
 	unsigned int dif=curtime-lastSensorUpdateTime;
 	lastSensorUpdateTime=curtime;
 	for(unsigned int i=0; i<evtBuf.size(); i++)
@@ -404,8 +409,8 @@ void WorldState::chkEvent(std::vector<EventBase*>& evtBuf, unsigned int sid, flo
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.24 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.26 $
  * $State: Exp $
- * $Date: 2004/05/08 03:03:32 $
+ * $Date: 2004/11/04 19:45:17 $
  */
