@@ -17,8 +17,14 @@ SoundManager * sndman=NULL;
 typedef LockScope<ProcessID::NumProcesses> AutoLock;
 
 SoundManager::SoundManager()
-	: sndlist(),playlist(),chanlist(),mix_mode(Fast),queue_mode(Override),max_chan(4),lock()
-{}
+	: mixerBuffer(0), mixerBufferSize(0),
+		sndlist(),playlist(),chanlist(),mix_mode(Fast),queue_mode(Override),max_chan(4),lock()
+{
+}
+
+SoundManager::~SoundManager() {
+	delete[] mixerBuffer;
+}
 
 void
 SoundManager::InitAccess(OSubject* subj) {
@@ -29,6 +35,10 @@ SoundManager::InitAccess(OSubject* subj) {
 SoundManager::Snd_ID
 SoundManager::LoadFile(std::string const &name) {
 	AutoLock autolock(lock,ProcessID::getID());
+	if (name.size() == 0) {
+	  cout << "SoundManager::LoadFile() null filename" << endl;
+	  return invalid_Snd_ID;
+	};
 	std::string path(config->sound.makePath(name));
 	Snd_ID id=lookupPath(path);
 	if(id!=invalid_Snd_ID) {
@@ -38,7 +48,7 @@ SoundManager::LoadFile(std::string const &name) {
 		//		cout << "load new file" << endl;
 		struct stat buf;
 		if(stat(path.c_str(),&buf)==-1) {
-			cout << "SoundManager::LoadFile(): Sound file not found " << name << endl;
+			cout << "SoundManager::LoadFile(): Sound file not found: " << path << endl;
 			return invalid_Snd_ID;
 		}
 		byte * sndbuf=new byte[buf.st_size];
@@ -47,7 +57,8 @@ SoundManager::LoadFile(std::string const &name) {
 		WAV wav;
 		WAVError error = wav.Set(sndbuf);
 		if (error != WAV_SUCCESS) {
-			OSYSLOG1((osyslogERROR, "%s : %s %d","SoundManager::LoadFile()","wav.Set() FAILED", error));
+			OSYSLOG1((osyslogERROR, "%s : %s %d: '%s'","SoundManager::LoadFile()","wav.Set() FAILED",
+				  error, path.c_str()));
 			return invalid_Snd_ID;
 		}
 		if(wav.GetSamplingRate()!=config->sound.sample_rate || wav.GetBitsPerSample()!=config->sound.sample_bits) {
@@ -316,188 +327,175 @@ SoundManager::GetRemainTime(Play_ID id) const {
 	return t/bytesPerMS;
 }
 
+void
+SoundManager::MixChannel(Play_ID channelId, void* buf, size_t destSize) {
+	char *dest = (char*) buf;
+	
+	PlayState& channel = playlist[channelId];
+	while (destSize > 0) {
+		const SoundData& buffer = sndlist[channel.snd_id];
+		const char* samples = ((char*) (buffer.data)) + channel.offset;
+		const unsigned int samplesSize = buffer.len - channel.offset;
+		if (samplesSize > destSize) {
+			memcpy(dest, samples, destSize);
+			channel.offset += destSize;
+			dest += destSize;
+			destSize = 0;
+			return;
+		} else {
+			memcpy(dest, samples, samplesSize);
+			channel.offset += samplesSize;
+			dest += samplesSize;
+			destSize -= samplesSize;
+			if (endPlay(channelId)) {
+				break;
+			}
+		}
+	}
+	if (destSize > 0) {
+		memset(dest, 0, destSize);
+	}
+}
+
+void
+SoundManager::MixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode,
+                                   short scalingFactor, void* buf, size_t destSize)
+{
+	PlayState& channel = playlist[channelId];
+	while (destSize > 0) {
+		const SoundData& buffer = sndlist[channel.snd_id];
+		const unsigned int samplesSize = buffer.len - channel.offset;
+		const unsigned int mixedSamplesSize =
+			((mode == Fast)
+				? ((samplesSize > destSize) ? destSize : samplesSize)
+				: ((samplesSize > destSize / 2) ? destSize / 2 : samplesSize)); 
+		
+		if (bitsPerSample == 8) {
+			//  8-bit mode
+			const char* samples = (char*) (buffer.data + channel.offset);
+			if (mode == Fast) {
+				// 8-bit mixing
+				char *dest = (char*) buf;
+				for (size_t i = 0; i < mixedSamplesSize; i++) {
+					*dest += samples[i] / scalingFactor;
+					dest++;
+				}
+				destSize -= (char*) dest - (char*) buf;
+				buf = dest;
+			} else {
+				// 16-bit mixing
+				short* dest = (short*) buf;
+				for (size_t i = 0; i < mixedSamplesSize; i++) {
+					*dest += samples[i];
+					*dest++;
+				}
+				destSize -= (char*) dest - (char*) buf;
+				buf = dest;
+			}
+		} else {
+			// 16-bit mode
+			const short* samples = (short*) (buffer.data + channel.offset);
+			if (mode == Fast) {
+				// 16-bit mixing
+				short* dest = (short*) buf;
+				for (size_t i = 0; i < mixedSamplesSize / 2; i++) {
+					*dest += samples[i] / scalingFactor;
+					*dest++;
+				}
+				destSize -= (char*) dest - (char*) buf;
+				buf = dest;
+			} else {
+				// 32-bit mixing
+				int* dest = (int*) buf;
+				for (size_t i = 0; i < mixedSamplesSize / 2; i++) {
+					*dest += samples[i];
+					*dest++;
+				}
+				destSize -= (char*) dest - (char*) buf;
+				buf = dest;
+			}
+		}
+		channel.offset += mixedSamplesSize;
+		if (destSize == 0) {
+			return;
+		} else {
+			if (endPlay(channelId)) {
+				return;
+			}
+		}
+	}
+}
+
 unsigned int
 SoundManager::CopyTo(OSoundVectorData* data) {
 	AutoLock autolock(lock,ProcessID::getID());
 
-	size_t avail  = data->GetInfo(0)->dataSize;	
-	byte*  dest   = data->GetData(0);
-	byte*  end    = dest+avail;
+	size_t destSize = data->GetInfo(0)->dataSize;	
+	void* dest = data->GetData(0);
 	
-	if(chanlist.size()==0) {
-		memset(dest,0,avail);
+	if(chanlist.size() == 0) {
+		memset(dest, 0, destSize);
 		return 0;
 	}
 
-	std::vector<Play_ID> mixs;
-	selectChannels(mixs);
+	std::vector<Play_ID> channels;
+	selectChannels(channels);
 
-	std::vector<byte*> srcs;
-	std::vector<byte*> ends;
-	for(std::vector<Play_ID>::iterator it=mixs.begin(); it!=mixs.end(); it++) {
-		Snd_ID cursnd=playlist[*it].snd_id;
-		srcs.push_back(sndlist[cursnd].data+playlist[*it].offset);
-		ends.push_back(sndlist[cursnd].data+sndlist[cursnd].len);
-	}
-
-	if(mixs.size()==0) { // nothing right now, but one's coming
-		memset(dest,0,avail);
-		return 1;
-	} else if(mixs.size()==1) { // only 1, just copy it directly (most common case)
-		size_t remain=ends.front()-srcs.front();
-		if(remain>=avail) { //just copy a buffer's worth
-			memcpy(dest,srcs.front(),avail);
-			playlist[mixs.front()].offset+=avail;
-			updateChannels(mixs,avail);
-			return 1;
-		} else { //copy what remains, 0 the rest
-			memcpy(dest,srcs.front(),remain);
-			memset(dest+remain,0,avail-remain);
-			playlist[mixs.front()].offset=sndlist[playlist[mixs.front()].snd_id].len;
-			endPlay(mixs.front());
-			return 0;
+	if (channels.size() == 0) {
+		// No channels to mix
+		memset(dest, 0, destSize); 
+	} else if (channels.size() == 1) {
+		// One channel to mix
+		MixChannel(channels.front(), dest, destSize);
+	} else {
+		// Several channels to mix	
+		const MixMode_t mode = mix_mode;
+		const int bitsPerSample = config->sound.sample_bits;
+		if (mode == Quality) {
+			// Quality mixing uses an intermediate buffer
+			if ((mixerBuffer == 0) || (mixerBufferSize < destSize * 2)) {
+				delete[] mixerBuffer;
+				mixerBuffer = 0;
+				mixerBufferSize = destSize * 2;
+				mixerBuffer = new int[(mixerBufferSize / 4) + 1]; // makes sure it's int-aligned
+			}
+			memset(mixerBuffer, 0,  mixerBufferSize);
+			dest = mixerBuffer;
+			destSize *= 2;
+		} else {
+			// Fast mixing does not use the intermeridate buffer
+			memset(dest, 0, destSize);
 		}
-	} else { // do a mix
-		if(mix_mode==Fast) { //essentially the same as quality mode below, but rounds off low order bits early
-			byte* begin=dest;
-			unsigned int stopped=0;
-			if(config->sound.sample_bits==8) { // have to mix, 8 bit
-				char size=srcs.size();
-				//just the first one, set dest
-				for(unsigned int c=0; c<1; c++) {
-					if((size_t)(ends[c]-srcs[c])>avail) {
-						for(dest=begin;dest<end;dest++) {
-							*dest=(*(char*)srcs[c])/size;
-							srcs[c]++;
-						}
-					} else {
-						for(dest=begin;srcs[c]<ends[c];srcs[c]++) {
-							*dest=(*(char*)srcs[c])/size;
-							dest++;
-						}
-						playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-						endPlay(mixs[c]);
-						stopped++;
-						memset(dest,0,end-dest); //zero out the rest
-					}							
-				}
-				//the rest, add to dest
-				for(unsigned int c=1; c<srcs.size(); c++) {
-					if((size_t)(ends[c]-srcs[c])>avail) {
-						for(dest=begin;dest<end;dest++) {
-							*dest+=(*(char*)srcs[c])/size;
-							srcs[c]++;
-						}
-					} else {
-						for(dest=begin;srcs[c]<ends[c];srcs[c]++) {
-							*dest+=(*(char*)srcs[c])/size;
-							dest++;
-						}
-						playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-						endPlay(mixs[c]);
-						stopped++;
-					}							
-				}
-			} else { // have to mix,  16 bit
-				short size=srcs.size();
-				//just the first one, set dest
-				for(unsigned int c=0; c<1; c++) {
-					if((size_t)(ends[c]-srcs[c])>avail) {
-						for(dest=begin;dest<end;dest+=2) {
-							*(short*)dest=(*(short*)srcs[c])/size;
-							srcs[c]+=2;
-						}
-					} else {
-						for(dest=begin;srcs[c]<ends[c];srcs[c]+=2) {
-							*(short*)dest=(*(short*)srcs[c])/size;
-							dest+=2;
-						}
-						playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-						endPlay(mixs[c]);
-						stopped++;
-						memset(dest,0,end-dest); //zero out the rest
-					}
-				}
-				//the rest, add to dest
-				for(unsigned int c=1; c<srcs.size(); c++) {
-					if((size_t)(ends[c]-srcs[c])>avail) {
-						for(dest=begin;dest<end;dest+=2) {
-							*(short*)dest+=(*(short*)srcs[c])/size;
-							srcs[c]+=2;
-						}
-					} else {
-						for(dest=begin;srcs[c]<ends[c];srcs[c]+=2) {
-							*(short*)dest+=(*(short*)srcs[c])/size;
-							dest+=2;
-						}
-						playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-						endPlay(mixs[c]);
-						stopped++;
-					}
+		
+		const int channelCount = channels.size();
+		const short scalingFactor = (short) ((mode == Fast) ? channelCount : 1);  
+		for(std::vector<Play_ID>::iterator i = channels.begin(); i != channels.end(); i++)
+			MixChannelAdditively(*i, bitsPerSample, mode, scalingFactor, dest, destSize);
+		
+		if (mode == Quality) {
+			// Quality mixing uses an intermediate buffer
+			// Scale the buffer
+			destSize /= 2;
+			if (bitsPerSample == 8) {
+				//  8-bit mode
+				char* destChar = (char*) data->GetData(0);
+				short* mixerBufferShort = (short*) mixerBuffer;
+				for (size_t i = 0; i < destSize; i++) {
+					destChar[i] = (char) (mixerBufferShort[i] / channelCount);
+				} 
+			} else {
+				// 16-bit mode
+				short* destShort = (short*) data->GetData(0);
+				const size_t destSampleCount = destSize / 2; 
+				for (size_t i = 0; i < destSampleCount; i++) {
+					destShort[i] = (short) (mixerBuffer[i] / channelCount);
 				}
 			}
-			for(unsigned int c=0; c<mixs.size(); c++)
-				playlist[mixs[c]].offset+=avail;
-			updateChannels(mixs,avail);
-			return mixs.size()-stopped;
-		} else { //mix_mode==quality
-			if(config->sound.sample_bits==8) { // have to mix, 8 bit
-				for(;dest!=end;dest++) {
-					short total=0;
-					for(unsigned int c=0; c<srcs.size(); c++) {
-						if(srcs[c]==ends[c]) {
-							playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-							if(endPlay(mixs[c])) {
-								std::swap(mixs[c],mixs.back());
-								std::swap(srcs[c],srcs.back());
-								std::swap(ends[c],ends.back());
-								mixs.pop_back();
-								srcs.pop_back();
-								ends.pop_back();
-								if(srcs.size()==0) {
-									memset(dest,0,end-dest);
-									return 0;
-								}
-								continue;
-							}
-						}
-						total+=*(char*)srcs[c];
-						srcs[c]++;
-					}
-					*dest=total/(int)srcs.size();
-				}
-			} else { // have to mix,  16 bit
-				for(;dest!=end;dest+=2) {
-					int total=0;
-					for(unsigned int c=0; c<srcs.size(); c++) {
-						if(srcs[c]==ends[c]) {
-							playlist[mixs[c]].offset=sndlist[playlist[mixs[c]].snd_id].len;
-							if(endPlay(mixs[c])) {
-								std::swap(mixs[c],mixs.back());
-								std::swap(srcs[c],srcs.back());
-								std::swap(ends[c],ends.back());
-								mixs.pop_back();
-								srcs.pop_back();
-								ends.pop_back();
-								if(srcs.size()==0) {
-									memset(dest,0,end-dest);
-									return 0;
-								}
-								continue;
-							}
-						}
-						total+=*(short*)srcs[c];
-						srcs[c]+=2;
-					}
-					*(short*)dest=total/(int)srcs.size();
-				}
-			}
-			for(unsigned int c=0; c<mixs.size(); c++)
-				playlist[mixs[c]].offset+=avail;
-			updateChannels(mixs,avail);
-			return mixs.size();
-		} // endif mix_mode==quality
-	} // endif do a mix
+		}
+	}
+	
+	updateChannels(channels, data->GetInfo(0)->dataSize);
+	return channels.size(); 
 }
 
 void
@@ -612,14 +610,26 @@ SoundManager::updateChannels(const std::vector<Play_ID>& mixs,size_t used) {
 				break;
 		}
 		for(;it!=chanlist.end(); it=chanlist.next(it)) {
-			Snd_ID cursnd=playlist[chanlist[it]].snd_id;
-			if(sndlist[cursnd].data!=NULL) {
-				size_t remain = sndlist[cursnd].len-playlist[chanlist[it]].offset;
-				if(remain<used) {
-					playlist[chanlist[it]].offset=sndlist[playlist[chanlist[it]].snd_id].len;
-					endPlay(chanlist[it]);
+			const Play_ID channelId = chanlist[it];
+			PlayState &channel = playlist[channelId];
+			size_t skip = used;
+			while (skip > 0) {
+				SoundData &buffer = sndlist[channel.snd_id];
+				// FIXME: Don't know why the buffer.data != 0 check is done 
+				if (buffer.data != 0) {
+					size_t remain = buffer.len - channel.offset;
+					if (remain < skip) {
+						channel.offset = buffer.len;
+						skip -= buffer.len;
+						if (endPlay(channelId)) {
+							break;
+						}
+					} else {
+						channel.offset += skip;
+						skip = 0;
+					}
 				} else {
-					playlist[chanlist[it]].offset+=used;
+					break;
 				}
 			}
 		}
@@ -665,11 +675,11 @@ SoundManager::PlayState::PlayState()
  * @brief Implements SoundManager, which provides sound effects and caching services, as well as mixing buffers for the SoundPlay process
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.15 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2004/10/08 00:07:25 $
+ * $Date: 2004/11/04 05:24:03 $
  */
 
 
