@@ -52,6 +52,7 @@ class SoundManager {
 public:
 	//!constructor
 	SoundManager();
+	virtual ~SoundManager();
 
 	//!This is used for referring to sound data so you can start playing it or release it
 	typedef SoundManagerMsg::Snd_ID Snd_ID;
@@ -68,8 +69,9 @@ public:
 	//!Used to set the mode for mixing multiple sound channels
 	/*!Feel free to add a higher quality mixer if you're an audiophile - I'm pretty new to sound processing*/
 	enum MixMode_t {
-		Fast,    //!< uses bit shifting trick, but can result in reduced volume with more active channels, best if you set max_channels to a power of 2
-		Quality  //!< uses real division to maintain volume level, although still a rather naive (but relatively fast) algorithm
+		// there's some prototype code for a bit-shifting 'Faster' quality level, but it hasn't been finished... 'Fast' is the default for now.
+		Fast,    //!< uses real division to maintain volume level, without increasing intermediary precision, which causes low-order bit error in exchange for less CPU usage
+		Quality  //!< uses real division to maintain volume level, using an intermediary higher precision buffer for mixing
 	};
 
 	enum QueueMode_t {
@@ -170,6 +172,20 @@ public:
 	unsigned int GetNumPlaying() { return chanlist.size(); }
 	
 protected:
+	//!Mixes the channel into the buffer
+	void MixChannel(Play_ID channelId, void* buf, size_t size);
+	
+	//!Mixes the channel into the buffer additively
+	/*!If mode is Quality, then the size of the buffer should be double the normal
+	* size. */
+	void MixChannelAdditively(Play_ID channelId, int bitsPerSample, MixMode_t mode, short scalingFactor, void* buf, size_t size);
+	
+	//!The intermediate mixer buffer used for Quality mode mixing
+	int* mixerBuffer;
+	
+	//!Size (in bytes) of the intermediate mixer buffer
+	size_t mixerBufferSize;
+
 	//!Sets up a shared region to hold a sound - rounds to nearest page size
 	static RCRegion* initRegion(unsigned int size);
 
@@ -245,11 +261,11 @@ extern SoundManager * sndman;
  * @brief Describes SoundManager, which provides sound effects and caching services, as well as mixing buffers for the SoundPlay process
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.12 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/10/08 00:07:25 $
+ * $Date: 2004/11/04 05:24:03 $
  */
 
 #endif
