@@ -1,5 +1,5 @@
 //
-// Copyright 2002 Sony Corporation 
+// Copyright 2002,2003 Sony Corporation 
 //
 // Permission to use, copy, modify, and redistribute this software for
 // non-commercial use is hereby granted.
@@ -34,27 +34,27 @@ public:
     virtual OStatus DoStop   (const OSystemEvent& event);
     virtual OStatus DoDestroy(const OSystemEvent& event);
 
-    void ListenContforPI  (void* msg);
-    void SendContforPI    (void* msg);
-    void ReceiveContforPI (void* msg);
-    void CloseContforPI   (void* msg);
-    void ConnectContforDTP(void* msg);
-    void SendContforDTP   (void* msg);
-    void ReceiveContforDTP(void* msg);
-    void CloseContforDTP  (void* msg);
+    void ListenContforPI  (ANTENVMSG msg);
+    void SendContforPI    (ANTENVMSG msg);
+    void ReceiveContforPI (ANTENVMSG msg);
+    void CloseContforPI   (ANTENVMSG msg);
+    void ListenContforDTP (ANTENVMSG msg);
+    void ConnectContforDTP(ANTENVMSG msg);
+    void SendContforDTP   (ANTENVMSG msg);
+    void ReceiveContforDTP(ANTENVMSG msg);
+    void CloseContforDTP  (ANTENVMSG msg);
 
 private:
     OStatus LoadPasswd();
     OStatus Load(char* path, byte** data, size_t* size);
 
-    OID            myOID;
-    OID            ipstackOID;
+    antStackRef ipstackRef;
     FtpPI ftpPI[FTP_CONNECTION_MAX];
 
     OList<Passwd, MAX_LOGIN> passwd;
 
-		TinyFTPD(const TinyFTPD&); //!< don't call
-		TinyFTPD& operator=(const TinyFTPD&); //!< don't call
+		TinyFTPD(const TinyFTPD&); //CHANGE_ET copy constructor, don't call
+		TinyFTPD operator=(const TinyFTPD&); //CHANGE_ET assignment operator, don't call
 };
-#endif /* _TinyFTPD_h_DEFINED */
 
+#endif /* _TinyFTPD_h_DEFINED */
