@@ -18,8 +18,8 @@ BallDetectionGenerator::BallDetectionGenerator(EventBase::EventGeneratorID_t gid
 void
 BallDetectionGenerator::processEvent(const EventBase& e) {
 	PROFSECTION("BallDetection::processEvent()",state->mainProfile);
-
-	if(!erouter->hasListeners(getGeneratorID(),getSourceID()))
+	EventGeneratorBase::processEvent(e);
+	if(e.getGeneratorID()!=getListenGeneratorID() || e.getSourceID()!=getListenSourceID())
 		return;
 
 	const SegmentedColorFilterBankEvent * segev=dynamic_cast<const SegmentedColorFilterBankEvent*>(&e);
@@ -276,8 +276,8 @@ BallDetectionGenerator::calcEdgeMask(int x1,int x2,int y1,int y2, int width, int
  * reviewed the code, so I guess it's all ours...
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:58 $
+ * $Date: 2004/11/09 20:01:49 $
  */
