@@ -23,6 +23,10 @@ CDTGenerator::CDTGenerator(unsigned int numRawLayers, unsigned int numCalcLayers
  */
 void
 CDTGenerator::processEvent(const EventBase& event) {
+	EventGeneratorBase::processEvent(event);
+	if(event.getGeneratorID()!=getListenGeneratorID() || event.getSourceID()!=getListenSourceID())
+		return;
+
 	typedef DataEvent<const OFbkImageVectorData*> OFbkEvent;
 	const OFbkEvent& fbkevent=dynamic_cast<const OFbkEvent& >(event);
 	OFbkImageVectorData& fbkdat=*const_cast<OFbkImageVectorData*>(fbkevent.getData());
@@ -233,9 +237,9 @@ CDTGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
