@@ -2,6 +2,8 @@
 #include "Events/FilterBankEvent.h"
 #include "Events/EventRouter.h"
 
+using namespace std;
+
 unsigned char *
 FilterBankGenerator::getImage(unsigned int layer, unsigned int channel) const {
 	//for(int i=0;i<1000;i++)
@@ -33,16 +35,20 @@ FilterBankGenerator::invalidateCaches() {
 
 void
 FilterBankGenerator::processEvent(const EventBase & event) {
-	const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
-	src=fbkevent.getSource();
-	frameNumber=src->getFrameNumber();
-	setNumImages(src->getNumLayers(),src->getNumChannels());
-	if(numLayers>0 && (src->getWidth(numLayers-1)!=getWidth(numLayers-1) || src->getHeight(numLayers-1)!=getHeight(numLayers-1))) {
-		ASSERT(widths[numLayers-1]==0,"Strange, the image dim changed after initial setting" << widths[numLayers-1] << ' ' << heights[numLayers-1]);
-		setDimensions();
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID()) {
+		const FilterBankEvent& fbkevent=dynamic_cast<const FilterBankEvent& >(event);
+		src=fbkevent.getSource();
+		frameNumber=src->getFrameNumber();
+		setNumImages(src->getNumLayers(),src->getNumChannels());
+		if(numLayers>0 && (src->getWidth(numLayers-1)!=getWidth(numLayers-1) || src->getHeight(numLayers-1)!=getHeight(numLayers-1))) {
+			ASSERT(widths[numLayers-1]==0,"Strange, the image dim changed after initial setting" << widths[numLayers-1] << ' ' << heights[numLayers-1]);
+			setDimensions();
+		}
+		invalidateCaches();
+		framesProcessed++;
+	} else {
+		EventGeneratorBase::processEvent(event);
 	}
-	invalidateCaches();
-	framesProcessed++;
 }
 
 unsigned int FilterBankGenerator::getBinSize() const {
@@ -158,9 +164,9 @@ FilterBankGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
