@@ -111,11 +111,6 @@
  */
 class FilterBankGenerator : public EventGeneratorBase, public LoadSave {
 public:
-	//! constructor
-	FilterBankGenerator()
-		: EventGeneratorBase(), src(NULL), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
-	{	}
-
 	//! constructor
 	FilterBankGenerator(const std::string& name,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid, EventBase::EventGeneratorID_t mgid, unsigned int msid)
 		: EventGeneratorBase(name,mgid,msid,srcgid,srcsid), src(NULL), numLayers(0), numChannels(0), widths(NULL), heights(NULL), skips(NULL), strides(NULL), increments(NULL), images(NULL), imageValids(NULL), selectedSaveLayer(0), selectedSaveChannel(0), frameNumber(0), framesProcessed(0)
@@ -285,10 +280,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/11 01:45:37 $
  */
 
 #endif
