@@ -17,7 +17,8 @@ InterleavedYUVGenerator::InterleavedYUVGenerator(EventBase::EventGeneratorID_t g
 void
 InterleavedYUVGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
-	erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID())
+		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
 }
 
 unsigned int
@@ -127,9 +128,9 @@ InterleavedYUVGenerator::calcImage(unsigned int layer, unsigned int chan) const
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
