@@ -47,13 +47,15 @@ JPEGGenerator::~JPEGGenerator() {
 void
 JPEGGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
-	if(getSourceMode()==SRC_AUTO) { //if not auto, curMode was already set when srcMode was set
-		if(dynamic_cast<const InterleavedYUVGenerator*>(src)!=NULL)
-			curMode=SRC_COLOR;
-		else
-			curMode=SRC_GRAYSCALE;
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID()) {
+		if(getSourceMode()==SRC_AUTO) { //if not auto, curMode was already set when srcMode was set
+			if(dynamic_cast<const InterleavedYUVGenerator*>(src)!=NULL)
+				curMode=SRC_COLOR;
+			else
+				curMode=SRC_GRAYSCALE;
+		}
+		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
 	}
-	erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
 }
 
 unsigned int
@@ -239,9 +241,9 @@ JPEGGenerator::destruct() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
