@@ -13,10 +13,12 @@ RLEGenerator::RLEGenerator(EventBase::EventGeneratorID_t gid, unsigned int sid,
 void
 RLEGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
-	if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&event))
-		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segsrc));
-	else
-		erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID()) {
+		if(const SegmentedColorFilterBankEvent * segsrc=dynamic_cast<const SegmentedColorFilterBankEvent *>(&event))
+			erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segsrc));
+		else
+			erouter->postEvent(new FilterBankEvent(this,getGeneratorID(),getSourceID()));
+	}
 }
 
 unsigned int
@@ -147,9 +149,9 @@ RLEGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
