@@ -23,6 +23,9 @@ RawCameraGenerator::RawCameraGenerator(unsigned int numRawLayers, unsigned int n
  */
 void
 RawCameraGenerator::processEvent(const EventBase& event) {
+	EventGeneratorBase::processEvent(event);
+	if(event.getGeneratorID()!=getListenGeneratorID() || event.getSourceID()!=getListenSourceID())
+		return;
 	typedef DataEvent<const OFbkImageVectorData*> OFbkEvent;
 	const OFbkEvent& fbkevent=dynamic_cast<const OFbkEvent& >(event);
 	OFbkImageVectorData& fbkdat=*const_cast<OFbkImageVectorData*>(fbkevent.getData());
@@ -422,9 +425,9 @@ RawCameraGenerator::reconstructImage() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.15 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
