@@ -24,21 +24,23 @@ RegionGenerator::freeCaches() {
 void
 RegionGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
-	const RLEGenerator * rle=dynamic_cast<const RLEGenerator*>(src);
-	if(NULL==rle) {
-		serr->printf("RegionGenerator's event %s is not from RLEGenerator\n",event.getName().c_str());
-		return;
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID()) {
+		const RLEGenerator * rle=dynamic_cast<const RLEGenerator*>(src);
+		if(NULL==rle) {
+			serr->printf("RegionGenerator's event %s is not from RLEGenerator\n",event.getName().c_str());
+			return;
+		}
+		const SegmentedColorFilterBankEvent * segev=dynamic_cast<const SegmentedColorFilterBankEvent*>(&event);
+		if(NULL==segev) {
+			serr->printf("RegionGenerator's event %s is not SegmentedColorFilterBankEvent\n",event.getName().c_str());
+			return;
+		}
+		if(srcNumColors!=segev->getNumColors())
+			freeCaches();
+		srcNumColors=segev->getNumColors();
+		srcColors=segev->getColors();
+		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segev));
 	}
-	const SegmentedColorFilterBankEvent * segev=dynamic_cast<const SegmentedColorFilterBankEvent*>(&event);
-	if(NULL==segev) {
-		serr->printf("RegionGenerator's event %s is not SegmentedColorFilterBankEvent\n",event.getName().c_str());
-		return;
-	}
-	if(srcNumColors!=segev->getNumColors())
-		freeCaches();
-	srcNumColors=segev->getNumColors();
-	srcColors=segev->getColors();
-	erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),*segev));
 }
 
 unsigned int
@@ -237,9 +239,9 @@ RegionGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
