@@ -31,7 +31,8 @@ SegmentedColorGenerator::~SegmentedColorGenerator() {
 void
 SegmentedColorGenerator::processEvent(const EventBase& event) {
 	FilterBankGenerator::processEvent(event);
-	erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),this,getNumColors(),getColors(),&colorNames));
+	if(event.getGeneratorID()==getListenGeneratorID() && event.getSourceID()==getListenSourceID())
+		erouter->postEvent(new SegmentedColorFilterBankEvent(this,getGeneratorID(),getSourceID(),this,getNumColors(),getColors(),&colorNames));
 }
 
 unsigned int
@@ -223,9 +224,9 @@ SegmentedColorGenerator::calcImage(unsigned int layer, unsigned int chan) const
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/02/18 21:13:32 $
+ * $Date: 2004/11/09 20:01:49 $
  */
 
