@@ -15,9 +15,13 @@
 #ifndef __CMV_REGION_H__
 #define __CMV_REGION_H__
 
+//@todo this should go away - ET
+const unsigned int MAX_COLORS=20;
+
+
 #include <stdio.h>
 //#include "Shared/Util.h"
-#include "Visiondefines.h"
+//#include "Visiondefines.h"
 
 #include "cmv_types.h"
 #include <ext/hash_map>
@@ -1061,7 +1065,7 @@ int find(data *arr,int start,int end,data key)
 using namespace __gnu_cxx;
 
 template <class color_class_state_t>
-int LoadColorInformation(color_class_state_t *color,int max,const char *filename, hash_map<const char*, int, hash<const char*>, hashcmp_eqstr> &color_names)
+int LoadColorInformation(color_class_state_t *color,int max,const char *filename, hash_map<const char*, unsigned int, hash<const char*>, hashcmp_eqstr> &color_names)
 {
   char buf[512];
   FILE *in;
