@@ -20,6 +20,7 @@
 #include "Behaviors/Demos/LookForSoundBehavior.h"
 #include "Behaviors/Demos/SimpleChaseBallBehavior.h"
 #include "Behaviors/Demos/StareAtBallBehavior.h"
+#include "Behaviors/Demos/WallTestBehavior.h"
 
 #include "Shared/ProjectInterface.h"
 
@@ -33,32 +34,33 @@ StartupBehavior::SetupModeSwitch() {
 		BehaviorSwitchControlBase::BehaviorGroup * bg = new BehaviorSwitchControlBase::BehaviorGroup();
 
 		//put behaviors here:
-		addItem(new BehaviorSwitchControl<HelloWorldBehavior>("HelloWorldBehavior",false));
+		addItem(new BehaviorSwitchControl<HelloWorldBehavior>("Hello World",false));
 		if(state->robotDesign&(WorldState::ERS210Mask|WorldState::ERS7Mask)) //this one only really works on the 210 or 7
-			addItem(new BehaviorSwitchControl<AlanBehavior>("AlanBehavior",bg,false));
-		addItem(new BehaviorSwitchControl<FollowHeadBehavior>("FollowHeadBehavior",bg,false));
-		addItem(new BehaviorSwitchControl<StareAtBallBehavior>("StareAtBallBehavior",false));
-		addItem(new BehaviorSwitchControl<SimpleChaseBallBehavior>("SimpleChaseBallBehavior",false));
-		addItem(new BehaviorSwitchControl<ChaseBallBehavior>("ChaseBallBehavior",bg,false));
-		addItem(new BehaviorSwitchControl<SoundTestBehavior>("SoundTestBehavior",bg,false));
-		addItem(new BehaviorSwitchControl<LookForSoundBehavior>("LookForSoundBehavior",bg,false));
+			addItem(new BehaviorSwitchControl<AlanBehavior>("Alan's Behavior",bg,false));
+		addItem(new BehaviorSwitchControl<FollowHeadBehavior>("Follow Head",bg,false));
+		addItem(new BehaviorSwitchControl<StareAtBallBehavior>("Stare at Pink Ball",false));
+		addItem(new BehaviorSwitchControl<SimpleChaseBallBehavior>("Simple Chase Ball",false));
+		addItem(new BehaviorSwitchControl<ChaseBallBehavior>("Chase Ball",bg,false));
+		addItem(new BehaviorSwitchControl<SoundTestBehavior>("Sound Test",bg,false));
+		addItem(new BehaviorSwitchControl<LookForSoundBehavior>("Look at Sound",bg,false));
 		addItem(new ControlBase("State Machine Demos","More fully developed demo applications"));
 		startSubMenu();
 		{
 			addItem(new BehaviorSwitchControlBase(new WalkToTargetMachine(ProjectInterface::visPinkBallSID),bg));
-			addItem(new BehaviorSwitchControl<BanditMachine>("BanditMachine",bg,false));
-			addItem(new BehaviorSwitchControl<ExploreMachine>("ExploreMachine",bg,false));
-			addItem(new BehaviorSwitchControl<PaceTargetsMachine>("PaceTargetsMachine",bg,false));
+			addItem(new BehaviorSwitchControl<BanditMachine>("Bandit State Machine",bg,false));
+			addItem(new BehaviorSwitchControl<ExploreMachine>("Explore State Machine",bg,false));
+			addItem(new BehaviorSwitchControl<PaceTargetsMachine>("Pace Targets State Machine",bg,false));
 		}
 		endSubMenu();
 		addItem(new ControlBase("Kinematics Demos","Showcases some of the newly developed kinematics code"));
 		startSubMenu();
 		{
-			addItem(new BehaviorSwitchControl<KinematicSampleBehavior>("KinematicSampleBehavior",bg,false));
-			addItem(new BehaviorSwitchControl<KinematicSampleBehavior2>("KinematicSampleBehavior2",bg,false));
-			addItem(new BehaviorSwitchControl<StareAtPawBehavior>("StareAtPawBehavior",bg,false));
-			addItem(new BehaviorSwitchControl<StareAtPawBehavior2>("StareAtPawBehavior2",bg,false));
-			addItem(new BehaviorSwitchControl<GroundPlaneBehavior>("GroundPlaneBehavior",bg,false));
+			addItem(new BehaviorSwitchControl<KinematicSampleBehavior>("Kinematic Sample 1",bg,false));
+			addItem(new BehaviorSwitchControl<KinematicSampleBehavior2>("Kinematic Sample 2",bg,false));
+			addItem(new BehaviorSwitchControl<StareAtPawBehavior>("Stare at Paw (pre-2.2)",bg,false));
+			addItem(new BehaviorSwitchControl<StareAtPawBehavior2>("New Stare at Paw",bg,false));
+			addItem(new BehaviorSwitchControl<GroundPlaneBehavior>("Ground Plane Test",bg,false));
+			addItem(new BehaviorSwitchControl<WallTestBehavior>("Wall Test",bg,false));
 		}
 		endSubMenu();
 	}
