@@ -12,6 +12,8 @@
 #include "Behaviors/Mon/RawCamBehavior.h"
 #include "Behaviors/Mon/SegCamBehavior.h"
 #include "Behaviors/Mon/WorldStateSerializerBehavior.h"
+#include "Behaviors/Mon/MicrophoneServer.h"
+#include "Behaviors/Mon/SpeakerServer.h"
 
 ControlBase*
 StartupBehavior::SetupTekkotsuMon() {
@@ -24,9 +26,11 @@ StartupBehavior::SetupTekkotsuMon() {
 		addItem((new BehaviorSwitchControl<WMMonitorBehavior>("Watchable Memory Monitor",false))->start());
 		addItem((new BehaviorSwitchControl<Aibo3DControllerBehavior>("Aibo 3D",false)));
 		addItem((new BehaviorSwitchControl<WorldStateSerializerBehavior>("World State Serializer",false)));
-		addItem((new BehaviorSwitchControl<RawCamBehavior>("RawCamServer",false)));
-		addItem((new BehaviorSwitchControl<SegCamBehavior>("SegCamServer",false)));
+		addItem((new BehaviorSwitchControl<RawCamBehavior>("Raw Cam Server",false)));
+		addItem((new BehaviorSwitchControl<SegCamBehavior>("Seg Cam Server",false)));
 		addItem((new BehaviorSwitchControlBase(new EStopControllerBehavior(stop_id)))->start());
+		addItem(new BehaviorSwitchControlBase(MicrophoneServer::GetInstance()));
+		addItem(new BehaviorSwitchControlBase(SpeakerServer::GetInstance()));
 	}
 	return endSubMenu();
 }
