@@ -12,7 +12,7 @@
 class CLASSNAME : public BehaviorBase {
 public:
 	//! constructor
-	CLASSNAME() : BehaviorBase() {}
+	CLASSNAME() : BehaviorBase("CLASSNAME") {}
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
@@ -29,9 +29,8 @@ public:
 		// you can delete this function if you don't use any events...
 	}
 
-	virtual std::string getName() const { return "CLASSNAME"; }
-
 	static std::string getClassDescription() { return "DESCRIPTION"; }
+	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
 	
@@ -42,10 +41,10 @@ protected:
  * @author YOURNAMEHERE (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2 $
- * $Revision: 1.1 $
+ * $Name: tekkotsu-2_2_1 $
+ * $Revision: 1.2 $
  * $State: Exp $
- * $Date: 2004/08/25 01:09:24 $
+ * $Date: 2004/11/11 20:35:00 $
  */
 
 #endif
