@@ -8,9 +8,10 @@ public class Joints {
   int timestamp;
 
   Joints() {
+      //note: this is old and for the ers2xx, but, eh. doesn't hurt to leave like this
     positions=new float[18];
     duties=new float[18];
-    sensors=new float[6];
+    sensors=new float[10];
     buttons=new float[8];
   } 
 
@@ -20,25 +21,25 @@ public class Joints {
 
   public String positionsString() {
     String ret="";
-    for (int i=0; i<18; i++) ret+=positions[i]+" ";
+    for (int i=0; i<positions.length; i++) ret+=positions[i]+" ";
     return ret+"\n";
   }
 
   public String dutiesString() {
     String ret="";
-    for (int i=0; i<18; i++) ret+=duties[i]+" ";
+    for (int i=0; i<duties.length; i++) ret+=duties[i]+" ";
     return ret+"\n";
   }
 
   public String sensorsString() {
     String ret="";
-    for (int i=0; i<6; i++) ret+=sensors[i]+" ";
+    for (int i=0; i<sensors.length; i++) ret+=sensors[i]+" ";
     return ret+"\n";
   }
 
   public String buttonsString() {
     String ret="";
-    for (int i=0; i<8; i++) ret+=buttons[i]+" ";
+    for (int i=0; i<buttons.length; i++) ret+=buttons[i]+" ";
     return ret+"\n";
   }
 
